from google.protobuf import timestamp_pb2 as _timestamp_pb2
from poly.handlers.protobuf import functions_pb2 as _functions_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EndFunctionReferences(_message.Message):
    __slots__ = ("variables",)
    class VariablesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bool
        def __init__(self, key: _Optional[str] = ..., value: bool = ...) -> None: ...
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    variables: _containers.ScalarMap[str, bool]
    def __init__(self, variables: _Optional[_Mapping[str, bool]] = ...) -> None: ...

class EndFunction(_message.Message):
    __slots__ = ("id", "name", "description", "parameters", "code", "errors", "created_at", "created_by", "updated_at", "updated_by", "archived", "references")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_FIELD_NUMBER: _ClassVar[int]
    REFERENCES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    parameters: _containers.RepeatedCompositeFieldContainer[_functions_pb2.FunctionParameter]
    code: str
    errors: _containers.RepeatedCompositeFieldContainer[_functions_pb2.FunctionError]
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    archived: bool
    references: EndFunctionReferences
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[_functions_pb2.FunctionParameter, _Mapping]]] = ..., code: _Optional[str] = ..., errors: _Optional[_Iterable[_Union[_functions_pb2.FunctionError, _Mapping]]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., archived: bool = ..., references: _Optional[_Union[EndFunctionReferences, _Mapping]] = ...) -> None: ...

class EndFunction_Create(_message.Message):
    __slots__ = ("id", "name", "description", "parameters", "code", "errors", "archived", "references")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_FIELD_NUMBER: _ClassVar[int]
    REFERENCES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    parameters: _containers.RepeatedCompositeFieldContainer[_functions_pb2.FunctionParameter]
    code: str
    errors: _containers.RepeatedCompositeFieldContainer[_functions_pb2.FunctionError]
    archived: bool
    references: EndFunctionReferences
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[_functions_pb2.FunctionParameter, _Mapping]]] = ..., code: _Optional[str] = ..., errors: _Optional[_Iterable[_Union[_functions_pb2.FunctionError, _Mapping]]] = ..., archived: bool = ..., references: _Optional[_Union[EndFunctionReferences, _Mapping]] = ...) -> None: ...

class EndFunction_Delete(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class EndFunction_Update(_message.Message):
    __slots__ = ("id", "description", "code", "errors", "references")
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    REFERENCES_FIELD_NUMBER: _ClassVar[int]
    id: str
    description: str
    code: str
    errors: _functions_pb2.ErrorsUpdate
    references: EndFunctionReferences
    def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., errors: _Optional[_Union[_functions_pb2.ErrorsUpdate, _Mapping]] = ..., references: _Optional[_Union[EndFunctionReferences, _Mapping]] = ...) -> None: ...



"""Constants for Agent Development Kit

Copyright PolyAI Limited
"""

PERMISSIONS = [
    "home",
    "conversations",
    "pii",
    "call_download",
    "intents",
    "entities",
    "metrics",
    "assistant_analysis",
    "custom_analytics",
    "safety_analytics",
    "about",
    "source_hub",
    "knowledge_base",
    "jupiter_flows",
    "functions",
    "as_api_integrations",
    "rules",
    "variant_management",
    "handoffs",
    "sms",
    "speech_recognition",
    "realtime_config_builder",
    "testing",
    "branch_management",
    "voice",
    "audio_cache",
    "response_control",
    "voice_channel",
    "webchat_channel",
    "environments",
    "settings",
    "numbers",
    "agent_config",
    "integrations",
    "custom_metrics",
    "realtime_config_manager",
    "webchat_configurations",
    "csat",
]



"""API Handler Interface for Agent Studio

Copyright PolyAI Limited"""

from typing import Any, Optional

from google.protobuf.message import Message

from poly.handlers.platform_api import PlatformAPIHandler
from poly.handlers.sync_client import SyncClientHandler
from poly.resources import BaseResource, Resource

REGIONS = [
    "us-1",
    "euw-1",
    "uk-1",
    "staging",
    "dev",
]


class AgentStudioInterface:
    """Interface for the Agent Studio API"""

    region: Optional[str] = None
    account_id: Optional[str] = None
    project_id: Optional[str] = None
    sync_client: Optional[SyncClientHandler] = None

    @property
    def branch_id(self) -> Optional[str]:
        """Get the current branch ID."""
        if not self.sync_client:
            return None
        return self.sync_client.branch_id

    def __init__(
        self,
        region: Optional[str] = None,
        account_id: Optional[str] = None,
        project_id: Optional[str] = None,
        branch_id: Optional[str] = None,
    ):
        self.region = region
        self.account_id = account_id
        self.project_id = project_id
        if region and account_id and project_id:
            self.sync_client = SyncClientHandler(region, account_id, project_id, branch_id)

    @staticmethod
    def get_accounts(region: str) -> dict[str, str]:
        """Get the accounts for a given region.

        Args:
            region (str): The region name

        Returns:
            dict[str, str]: A dictionary mapping account names to account IDs
        """
        return PlatformAPIHandler.get_accounts(region)

    @staticmethod
    def get_projects(region: str, account_id: str) -> dict[str, str]:
        """Get the projects for a given account.

        Args:
            region (str): The region name
            account_id (str): The account ID

        Returns:
            dict[str, str]: A dictionary mapping project names to project IDs
        """
        return PlatformAPIHandler.get_projects(region, account_id)

    @staticmethod
    def get_deployments(region: str, account_id: str, project_id: str) -> dict[str, str]:
        """Get the deployments for a given project.
        Args:
            region (str): The region name
            account_id (str): The account ID
            project_id (str): The project ID
        Returns:
            dict[str, str]: A dictionary mapping deployment versions to deployment IDs
        """
        return PlatformAPIHandler.get_deployments(region, account_id, project_id)

    @staticmethod
    def get_active_deployments(
        region: str, account_id: str, project_id: str
    ) -> dict[str, dict[str, str]]:
        """Get the active deployments for a given project.
        Args:
            region (str): The region name
            account_id (str): The account ID
            project_id (str): The project ID
        Returns:
            dict[str, dict[str, str]]: A dictionary mapping environments to deployment info
        """
        return PlatformAPIHandler.get_active_deployments(region, account_id, project_id)

    def pull_deployment_resources(
        self, deployment_id: str
    ) -> dict[type[Resource], dict[str, Resource]]:
        """Fetch all resources for a specific deployment of a project.
        Args:
            deployment_id (str): The deployment ID
        Returns:
            dict[type[Resource], dict[str, Resource]]: A dictionary mapping resource types to
                their resources
        """
        return self.sync_client.pull_deployment_resources(deployment_id)

    def pull_resources(
        self, projection_json: Optional[dict[str, Any]] = None
    ) -> tuple[dict[type[Resource], dict[str, Resource]], dict[str, Any]]:
        """Fetch all resources for the specific project.

        Args:
            projection_json (Optional[dict[str, Any]]): A dictionary containing the projection.
                If provided, the projection will be used instead of fetching it from the API.

        Returns:
            dict[type[Resource], dict[str, Resource]]: A dictionary mapping resource types to
                their resources
            dict[str, Any]: The projection data
        """
        if projection_json is not None:
            return SyncClientHandler.load_resources_from_projection(
                projection_json
            ), projection_json
        return self.sync_client.pull_resources()

    def push_resources(
        self,
        deleted_resources: dict[type[BaseResource], dict[str, BaseResource]],
        new_resources: dict[type[BaseResource], dict[str, BaseResource]],
        updated_resources: dict[type[BaseResource], dict[str, BaseResource]],
        dry_run: bool = False,
        queue_pushes: bool = False,
        email: Optional[str] = None,
    ) -> bool:
        """Upload multiple resources for the specific project.

        Args:
            new_resources (dict[type[BaseResource], dict[str, BaseResource]]): New resources to upload
            deleted_resources (dict[type[BaseResource], dict[str, BaseResource]]): Resources to delete
            updated_resources (dict[type[BaseResource], dict[str, BaseResource]]): Updated resources to upload
            dry_run (bool): If True, only log the upload actions without actually
                uploading
            queue_pushes (bool): If True, queue the resources for pushing.
            email (str): Email to use for metadata creation.
                If None, use the email of the current user.

        Returns:
            bool: True if the resources were pushed successfully, False otherwise
        """
        self.queue_resources(
            deleted_resources=deleted_resources,
            new_resources=new_resources,
            updated_resources=updated_resources,
            email=email,
        )

        if queue_pushes:
            return True

        if dry_run:
            self.clear_command_queue()
            return True

        return self.send_queued_commands()

    def queue_resources(
        self,
        deleted_resources: dict[type[BaseResource], dict[str, BaseResource]],
        new_resources: dict[type[BaseResource], dict[str, BaseResource]],
        updated_resources: dict[type[BaseResource], dict[str, BaseResource]],
        email: Optional[str] = None,
    ) -> list[Message]:
        """Queue multiple resources for the specific project.

        Args:
            deleted_resources (dict[type[BaseResource], dict[str, BaseResource]]): Resources to delete
            new_resources (dict[type[BaseResource], dict[str, BaseResource]]): New resources to upload
            updated_resources (dict[type[BaseResource], dict[str, BaseResource]]): Updated resources to upload
            email (str): Email to use for metadata creation.
                If None, use the email of the current user.

        Returns:
            list[Message]: A list of queued Command protobuf messages.
        """
        return self.sync_client.queue_resources(
            deleted_resources=deleted_resources,
            new_resources=new_resources,
            updated_resources=updated_resources,
            email=email,
        )

    def send_queued_commands(self) -> bool:
        """Send all queued commands as a batch and clear the queue.

        Returns:
            bool: True if the commands were sent successfully, False otherwise
        """
        return self.sync_client.send_queued_commands()

    def clear_command_queue(self) -> None:
        """Clear all queued commands without sending."""
        self.sync_client.clear_command_queue()

    def get_queued_commands(self) -> list[Message]:
        """Get all queued commands.

        Returns:
            list[Message]: A list of queued Command protobuf messages.
        """
        return self.sync_client.get_queued_commands()

    def get_branches(self) -> dict[str, str]:
        """Get a list of branches.

        Args:
            branch_name (str): The name of the branch

        Returns:
            dict[str, str]: A dictionary mapping branch names to branch IDs
        """
        return self.sync_client.get_branches()

    def create_branch(self, branch_name: Optional[str] = None) -> str:
        """Create a new branch in the project.

        Args:
            branch_name (str): The name of the new branch

        Returns:
            str: The ID of the newly created branch
        """
        return self.sync_client.create_branch(branch_name)

    def switch_branch(self, branch_id: str) -> bool:
        """Switch to a different branch in the project.

        Args:
            branch_name (str): The name of the branch to switch to

        Returns:
            bool: True if the branch was switched successfully, False otherwise
        """
        return self.sync_client.switch_branch(branch_id)

    def merge_branch(
        self, message: str, conflict_resolutions: Optional[list[dict[str, Any]]] = None
    ) -> tuple[bool, list[dict[str, str]], list[dict[str, str]]]:
        """Merge the current branch into main.

        Args:
            message (str): The merge commit message
            conflict_resolutions (list[dict[str, Any]]): A list of conflict resolutions. Each resolution should have:
                - path: List of strings representing the path to the conflicted field (e.g., ["users", "1", "name"])
                - strategy: Resolution strategy - "ours", "theirs", or "base"
                - value: Optional custom value (only used with custom strategy)

        Returns:
            success (bool): True if the merge was successful, False otherwise
            list[dict[str, str]]: A list of conflict information if the merge failed, empty list if successful
            list[dict[str, str]]: A list of error information if the merge failed, empty list if successful
        """
        return self.sync_client.merge_branch(message, conflict_resolutions)

    def delete_branch(self, branch_id: str) -> bool:
        """Delete a branch in the project.

        Args:
            branch_name (str): The name of the branch to delete

        Returns:
            bool: True if the branch was deleted successfully, False otherwise
        """
        return self.sync_client.delete_branch(branch_id)

    @staticmethod
    def create_chat(
        region: str,
        account_id: str,
        project_id: str,
        environment: str = "sandbox",
        variant_id: Optional[str] = None,
        channel: str = "chat.polyai",
    ) -> dict:
        """Create a new chat conversation.

        Args:
            region: The region name
            account_id: The account ID
            project_id: The project ID
            environment: The environment to chat against (sandbox, pre-release, live)
            variant_id: Optional variant ID (e.g. 'Voice')
            channel: The channel identifier (e.g. 'chat.polyai', 'webchat.polyai')

        Returns:
            dict: The API response containing the conversation ID and initial greeting
        """
        return PlatformAPIHandler.create_chat(
            region, account_id, project_id, environment, variant_id, channel
        )

    @staticmethod
    def send_chat_message(
        region: str,
        account_id: str,
        project_id: str,
        conversation_id: str,
        text: str,
        environment: str = "sandbox",
    ) -> dict:
        """Send a message to an existing chat conversation.

        Args:
            region: The region name
            account_id: The account ID
            project_id: The project ID
            conversation_id: The conversation ID
            text: The user message text
            environment: The environment (sandbox, pre-release, live)

        Returns:
            dict: The API response containing the assistant's reply
        """
        return PlatformAPIHandler.send_chat_message(
            region, account_id, project_id, conversation_id, text, environment
        )

    def get_branch_chat_info(self, branch_id: str) -> dict:
        """Get deployment versions needed to start a draft chat on a branch.

        Fetches the branch projection sequence from sourcerer, then
        prepares the deployment to obtain artifactVersion and
        lambdaDeploymentVersion.

        Args:
            branch_id: The branch ID

        Returns:
            dict with 'artifactVersion', 'lambdaDeploymentVersion', etc.
        """
        return self.sync_client.get_branch_chat_info(branch_id)

    @staticmethod
    def create_draft_chat(
        region: str,
        account_id: str,
        project_id: str,
        artifact_version: str,
        lambda_deployment_version: str,
        channel: str = "chat.polyai",
        variant_id: Optional[str] = None,
    ) -> dict:
        """Create a new chat conversation against a branch deployment.

        Args:
            region: The region name
            account_id: The account ID
            project_id: The project ID
            artifact_version: Branch artifact version from sourcerer
            lambda_deployment_version: Branch lambda version from sourcerer
            channel: The channel identifier (e.g. 'chat.polyai', 'webchat.polyai')
            variant_id: Optional variant ID (e.g. 'Voice')

        Returns:
            dict: The API response containing the conversation ID and initial greeting
        """
        return PlatformAPIHandler.create_draft_chat(
            region,
            account_id,
            project_id,
            artifact_version,
            lambda_deployment_version,
            channel,
            variant_id,
        )

    @staticmethod
    def send_draft_chat_message(
        region: str,
        account_id: str,
        project_id: str,
        conversation_id: str,
        text: str,
    ) -> dict:
        """Send a message to an existing draft chat conversation.

        Args:
            region: The region name
            account_id: The account ID
            project_id: The project ID
            conversation_id: The conversation ID
            text: The user message text

        Returns:
            dict: The API response containing the assistant's reply
        """
        return PlatformAPIHandler.send_draft_chat_message(
            region,
            account_id,
            project_id,
            conversation_id,
            text,
        )

    @staticmethod
    def end_chat(
        region: str,
        account_id: str,
        project_id: str,
        conversation_id: str,
        environment: str = "sandbox",
    ) -> dict:
        """End a chat conversation.

        Args:
            region: The region name
            account_id: The account ID
            project_id: The project ID
            conversation_id: The conversation ID
            environment: The environment (sandbox, pre-release, live)

        Returns:
            dict: The API response
        """
        return PlatformAPIHandler.end_chat(
            region, account_id, project_id, conversation_id, environment
        )



"""Handling and managing an Agent Studio SMS Templates

Copyright PolyAI Limited
"""

import os
from dataclasses import dataclass
from typing import ClassVar, Optional

import poly.resources.resource_utils as utils
from poly.handlers.protobuf.sms_pb2 import (
    SMS_CreateTemplate,
    SMS_DeleteTemplate,
    SMS_UpdateTemplate,
    SMSEnvPhoneNumbers,
    SMSTemplateReferences,
    UpdateSMSEnvPhoneNumbers,
)
from poly.resources.resource import MultiResourceYamlResource, ResourceMapping


@dataclass
class EnvPhoneNumbers:
    sandbox: str
    pre_release: str
    live: str

    def to_yaml_dict(self) -> dict:
        return {
            "sandbox": self.sandbox,
            "pre_release": self.pre_release,
            "live": self.live,
        }


@dataclass
class SMSTemplate(MultiResourceYamlResource):
    """SMS resource for ADK."""

    text: str
    env_phone_numbers: Optional[EnvPhoneNumbers]
    top_level_name: ClassVar[str] = "sms_templates"

    def __init__(
        self,
        *,
        resource_id: str,
        name: str,
        text: str,
        env_phone_numbers: EnvPhoneNumbers | dict | None = None,
    ):
        self.resource_id = resource_id
        self.name = name
        self.text = text
        if env_phone_numbers is None:
            self.env_phone_numbers = None
        elif isinstance(env_phone_numbers, EnvPhoneNumbers):
            self.env_phone_numbers = env_phone_numbers
        else:
            self.env_phone_numbers = EnvPhoneNumbers(
                sandbox=env_phone_numbers.get("sandbox", ""),
                pre_release=env_phone_numbers.get("pre_release")
                or env_phone_numbers.get("preRelease", ""),
                live=env_phone_numbers.get("live", ""),
            )

    @classmethod
    def to_pretty_dict(
        cls, d: dict, resource_mappings: list[ResourceMapping] = None, **kwargs
    ) -> dict:
        """Return the pretty dictionary."""
        d["text"] = utils.replace_resource_ids_with_names(d["text"], resource_mappings or [])
        return d

    def to_yaml_dict(self) -> dict:
        return {
            "name": self.name,
            "text": self.text,
            "env_phone_numbers": (
                self.env_phone_numbers.to_yaml_dict()
                if self.env_phone_numbers
                else {"sandbox": "", "pre_release": "", "live": ""}
            ),
        }

    @property
    def file_path(self) -> str:
        path_safe_name = utils.clean_name(self.name, lowercase=False)
        return os.path.join("config", "sms_templates.yaml", self.top_level_name, path_safe_name)

    @staticmethod
    def get_resource_prefix(**kwargs) -> str:
        return "twilio_sms"

    @classmethod
    def from_yaml_dict(
        cls, yaml_data: dict, resource_id: str, name: str, **kwargs
    ) -> "SMSTemplate":
        return cls(
            resource_id=resource_id,
            name=yaml_data.get("name", ""),
            text=yaml_data.get("text", ""),
            env_phone_numbers=yaml_data.get("env_phone_numbers", {}),
        )

    @property
    def command_type(self) -> str:
        return "sms_template"

    @property
    def delete_command_type(self) -> str:
        return "sms_delete_template"

    @property
    def create_command_type(self) -> str:
        return "sms_create_template"

    @property
    def update_command_type(self) -> str:
        return "sms_update_template"

    def build_update_proto(self) -> SMS_UpdateTemplate:
        return SMS_UpdateTemplate(
            id=self.resource_id,
            name=self.name,
            text=self.text,
            env_phone_numbers=UpdateSMSEnvPhoneNumbers(
                sandbox=self.env_phone_numbers.sandbox,
                pre_release=self.env_phone_numbers.pre_release,
                live=self.env_phone_numbers.live,
            ),
            active=True,
        )

    def build_delete_proto(self) -> SMS_DeleteTemplate:
        return SMS_DeleteTemplate(
            id=self.resource_id,
        )

    def build_create_proto(self) -> SMS_CreateTemplate:
        return SMS_CreateTemplate(
            id=self.resource_id,
            name=self.name,
            text=self.text,
            env_phone_numbers=SMSEnvPhoneNumbers(
                sandbox=self.env_phone_numbers.sandbox,
                pre_release=self.env_phone_numbers.pre_release,
                live=self.env_phone_numbers.live,
            ),
            references=SMSTemplateReferences(
                topics={},
                flow_steps={},
                variables={},
            ),
            active=True,
        )

    def validate(self, resource_mappings: list[ResourceMapping] = None, **kwargs) -> None:
        if not self.name:
            raise ValueError("Name is required")
        if not self.text:
            raise ValueError("Text is required")
        if not self.env_phone_numbers:
            raise ValueError("Env phone numbers are required")

        references = utils.get_references_from_prompt(
            self.text, ["variables"], raise_on_invalid=True
        )
        valid, invalid_references = utils.validate_references(references, resource_mappings)
        if not valid:
            raise ValueError(f"Invalid references: {invalid_references}")

    @staticmethod
    def discover_resources(base_path: str) -> list[str]:
        """Discover resources of this type in the given base path.

        Args:
            base_path (str): The base path to search for resources.

        Returns:
            list[str]: A list of file paths of discovered resources.
        """
        sms_templates_path = os.path.join(base_path, "config", "sms_templates.yaml")
        discovered_sms_templates: list[str] = []

        if not os.path.exists(sms_templates_path):
            return discovered_sms_templates

        yaml_dict = SMSTemplate._get_top_level_data(sms_templates_path)
        sms_templates: list[dict] = yaml_dict.get("sms_templates", []) if yaml_dict else []

        for sms_template in sms_templates:
            name = sms_template.get("name")
            if not name:
                continue
            path_safe_name = utils.clean_name(name, lowercase=False)
            discovered_sms_templates.append(
                os.path.join(sms_templates_path, SMSTemplate.top_level_name, path_safe_name)
            )

        return discovered_sms_templates



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from poly.handlers.protobuf import handoff_pb2 as handoff__pb2
from poly.handlers.protobuf import knowledge_base_pb2 as knowledge__base__pb2
from poly.handlers.protobuf import sms_pb2 as sms__pb2
from poly.handlers.protobuf import stop_keywords_pb2 as stop__keywords__pb2
from poly.handlers.protobuf import variant_pb2 as variant__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import languages_pb2 as languages__pb2
from poly.handlers.protobuf import transcript_corrections_pb2 as transcript__corrections__pb2
from poly.handlers.protobuf import flows_pb2 as flows__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2
from poly.handlers.protobuf import experimental_config_pb2 as experimental__config__pb2
from poly.handlers.protobuf import pronunciations_pb2 as pronunciations__pb2
from poly.handlers.protobuf import keyphrase_boosting_pb2 as keyphrase__boosting__pb2
from poly.handlers.protobuf import voice_pb2 as voice__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2
from poly.handlers.protobuf import start_function_pb2 as start__function__pb2
from poly.handlers.protobuf import end_function_pb2 as end__function__pb2
from poly.handlers.protobuf import entities_pb2 as entities__pb2
from poly.handlers.protobuf import api_integrations_pb2 as api__integrations__pb2
from poly.handlers.protobuf import variables_pb2 as variables__pb2
from poly.handlers.protobuf import translations_pb2 as translations__pb2
from poly.handlers.protobuf import channels_pb2 as channels__pb2
from poly.handlers.protobuf import csat_pb2 as csat__pb2
from poly.handlers.protobuf import integrations_pb2 as integrations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ommands.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\rhandoff.proto\x1a\x14knowledge_base.proto\x1a\tsms.proto\x1a\x13stop_keywords.proto\x1a\rvariant.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\x0flanguages.proto\x1a\x1ctranscript_corrections.proto\x1a\x0b\x66lows.proto\x1a\x14\x61gent_settings.proto\x1a\x19\x65xperimental_config.proto\x1a\x14pronunciations.proto\x1a\x18keyphrase_boosting.proto\x1a\x0bvoice.proto\x1a\x0f\x66unctions.proto\x1a\x14start_function.proto\x1a\x12\x65nd_function.proto\x1a\x0e\x65ntities.proto\x1a\x16\x61pi_integrations.proto\x1a\x0fvariables.proto\x1a\x12translations.proto\x1a\x0e\x63hannels.proto\x1a\ncsat.proto\x1a\x12integrations.proto\"N\n\x08Metadata\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\"\xa6N\n\x05\x45vent\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x12\n\ncommand_id\x18\x02 \x01(\t\x12\x34\n\x10server_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x08metadata\x18\xc8\x01 \x01(\x0b\x32\t.Metadata\x12\x41\n\x0c\x63reate_topic\x18\x04 \x01(\x0b\x32).knowledge_base.KnowledgeBase_CreateTopicH\x00\x12\x41\n\x0cupdate_topic\x18\x05 \x01(\x0b\x32).knowledge_base.KnowledgeBase_UpdateTopicH\x00\x12\x41\n\x0c\x64\x65lete_topic\x18\x06 \x01(\x0b\x32).knowledge_base.KnowledgeBase_DeleteTopicH\x00\x12\x43\n\rimport_topics\x18v \x01(\x0b\x32*.knowledge_base.KnowledgeBase_ImportTopicsH\x00\x12N\n\x13toggle_topic_status\x18w \x01(\x0b\x32/.knowledge_base.KnowledgeBase_ToggleTopicStatusH\x00\x12\x36\n\x13sms_create_template\x18\x07 \x01(\x0b\x32\x17.sms.SMS_CreateTemplateH\x00\x12\x36\n\x13sms_update_template\x18\x08 \x01(\x0b\x32\x17.sms.SMS_UpdateTemplateH\x00\x12\x36\n\x13sms_delete_template\x18\t \x01(\x0b\x32\x17.sms.SMS_DeleteTemplateH\x00\x12\x31\n\x0ehandoff_create\x18\n \x01(\x0b\x32\x17.handoff.Handoff_CreateH\x00\x12\x31\n\x0ehandoff_update\x18\x0b \x01(\x0b\x32\x17.handoff.Handoff_UpdateH\x00\x12\x31\n\x0ehandoff_delete\x18\x0c \x01(\x0b\x32\x17.handoff.Handoff_DeleteH\x00\x12:\n\x13handoff_set_default\x18. \x01(\x0b\x32\x1b.handoff.Handoff_SetDefaultH\x00\x12M\n\x1dhandoff_reset_handoff_configs\x18H \x01(\x0b\x32$.handoff.Handoff_ResetHandoffConfigsH\x00\x12\x32\n\x10\x63reate_flow_step\x18\x64 \x01(\x0b\x32\x16.flows.Flow_CreateStepH\x00\x12\x32\n\x10update_flow_step\x18\x65 \x01(\x0b\x32\x16.flows.Flow_UpdateStepH\x00\x12\x32\n\x10\x64\x65lete_flow_step\x18\x66 \x01(\x0b\x32\x16.flows.Flow_DeleteStepH\x00\x12\x43\n\x19update_flow_step_position\x18g \x01(\x0b\x32\x1e.flows.Flow_UpdateStepPositionH\x00\x12\x45\n\x1aupdate_flow_step_positions\x18h \x01(\x0b\x32\x1f.flows.Flow_UpdateStepPositionsH\x00\x12H\n\x1cupdate_flow_step_dtmf_config\x18i \x01(\x0b\x32 .flows.Flow_UpdateStepDtmfConfigH\x00\x12\x46\n\x1bupdate_flow_step_asr_config\x18j \x01(\x0b\x32\x1f.flows.Flow_UpdateStepAsrConfigH\x00\x12O\n\x1f\x63reate_flow_transition_function\x18k \x01(\x0b\x32$.flows.Flow_CreateTransitionFunctionH\x00\x12O\n\x1fupdate_flow_transition_function\x18l \x01(\x0b\x32$.flows.Flow_UpdateTransitionFunctionH\x00\x12O\n\x1f\x64\x65lete_flow_transition_function\x18m \x01(\x0b\x32$.flows.Flow_DeleteTransitionFunctionH\x00\x12-\n\x0b\x64\x65lete_flow\x18n \x01(\x0b\x32\x16.flows.Flow_DeleteFlowH\x00\x12-\n\x0b\x63reate_flow\x18o \x01(\x0b\x32\x16.flows.Flow_CreateFlowH\x00\x12-\n\x0bimport_flow\x18p \x01(\x0b\x32\x16.flows.Flow_ImportFlowH\x00\x12-\n\x0bupdate_flow\x18q \x01(\x0b\x32\x16.flows.Flow_UpdateFlowH\x00\x12m\n/update_flow_transition_function_latency_control\x18r \x01(\x0b\x32\x32.flows.Flow_UpdateTransitionFunctionLatencyControlH\x00\x12\x37\n\x13\x63reate_no_code_step\x18\xd6\x01 \x01(\x0b\x32\x17.flows.CreateNoCodeStepH\x00\x12\x37\n\x13update_no_code_step\x18\xd7\x01 \x01(\x0b\x32\x17.flows.UpdateNoCodeStepH\x00\x12\x37\n\x13\x64\x65lete_no_code_step\x18\xd8\x01 \x01(\x0b\x32\x17.flows.DeleteNoCodeStepH\x00\x12H\n\x1cupdate_no_code_step_position\x18\xd9\x01 \x01(\x0b\x32\x1f.flows.UpdateNoCodeStepPositionH\x00\x12\x41\n\x18\x63reate_no_code_condition\x18\xda\x01 \x01(\x0b\x32\x1c.flows.CreateNoCodeConditionH\x00\x12\x41\n\x18\x64\x65lete_no_code_condition\x18\xdb\x01 \x01(\x0b\x32\x1c.flows.DeleteNoCodeConditionH\x00\x12\x41\n\x18update_no_code_condition\x18\xdc\x01 \x01(\x0b\x32\x1c.flows.UpdateNoCodeConditionH\x00\x12R\n!update_no_code_condition_position\x18\xdd\x01 \x01(\x0b\x32$.flows.UpdateNoCodeConditionPositionH\x00\x12\x64\n+update_no_code_condition_exit_flow_position\x18\xde\x01 \x01(\x0b\x32,.flows.UpdateNoCodeConditionExitFlowPositionH\x00\x12\x38\n\x13move_flow_component\x18\xdf\x01 \x01(\x0b\x32\x18.flows.MoveFlowComponentH\x00\x12:\n\x14move_flow_components\x18\xe0\x01 \x01(\x0b\x32\x19.flows.MoveFlowComponentsH\x00\x12)\n\x0b\x63reate_step\x18\xb3\x02 \x01(\x0b\x32\x11.flows.CreateStepH\x00\x12)\n\x0bupdate_step\x18\xb4\x02 \x01(\x0b\x32\x11.flows.UpdateStepH\x00\x12)\n\x0b\x64\x65lete_step\x18\xb5\x02 \x01(\x0b\x32\x11.flows.DeleteStepH\x00\x12<\n\x15\x63reate_step_condition\x18\xb6\x02 \x01(\x0b\x32\x1a.flows.CreateStepConditionH\x00\x12<\n\x15update_step_condition\x18\xb7\x02 \x01(\x0b\x32\x1a.flows.UpdateStepConditionH\x00\x12<\n\x15\x64\x65lete_step_condition\x18\xb8\x02 \x01(\x0b\x32\x1a.flows.DeleteStepConditionH\x00\x12M\n\x1eupdate_step_condition_position\x18\xb9\x02 \x01(\x0b\x32\".flows.UpdateStepConditionPositionH\x00\x12\x44\n\x18variant_create_attribute\x18\x12 \x01(\x0b\x32 .variant.Variant_CreateAttributeH\x00\x12\x44\n\x18variant_update_attribute\x18\x13 \x01(\x0b\x32 .variant.Variant_UpdateAttributeH\x00\x12\x44\n\x18variant_delete_attribute\x18\x14 \x01(\x0b\x32 .variant.Variant_DeleteAttributeH\x00\x12@\n\x16variant_create_variant\x18\x15 \x01(\x0b\x32\x1e.variant.Variant_CreateVariantH\x00\x12@\n\x16variant_update_variant\x18\x16 \x01(\x0b\x32\x1e.variant.Variant_UpdateVariantH\x00\x12@\n\x16variant_delete_variant\x18\x17 \x01(\x0b\x32\x1e.variant.Variant_DeleteVariantH\x00\x12I\n\x1bvariant_set_default_variant\x18\x18 \x01(\x0b\x32\".variant.Variant_SetDefaultVariantH\x00\x12\x42\n\x17variant_import_variants\x18\x32 \x01(\x0b\x32\x1f.variant.Variant_ImportVariantsH\x00\x12\x41\n\x14stop_keywords_create\x18\x19 \x01(\x0b\x32!.stop_keywords.StopKeyword_CreateH\x00\x12\x41\n\x14stop_keywords_update\x18\x1a \x01(\x0b\x32!.stop_keywords.StopKeyword_UpdateH\x00\x12\x41\n\x14stop_keywords_delete\x18\x1b \x01(\x0b\x32!.stop_keywords.StopKeyword_DeleteH\x00\x12J\n\x13update_llm_settings\x18\x1c \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettingsH\x00\x12t\n\x1eupdate_content_filter_settings\x18\x1d \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettingsH\x00\x12J\n\x13update_asr_settings\x18\x1e \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettingsH\x00\x12M\n\x13update_tts_settings\x18\x1f \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageB\x02\x18\x01H\x00\x12X\n!languages_update_default_language\x18\xe4\x01 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageH\x00\x12\x43\n\x16languages_add_language\x18\xe5\x01 \x01(\x0b\x32 .languages.Languages_AddLanguageH\x00\x12I\n\x19languages_delete_language\x18\xe6\x01 \x01(\x0b\x32#.languages.Languages_DeleteLanguageH\x00\x12\x61\n!experimental_config_update_config\x18  \x01(\x0b\x32\x34.experimental_config.ExperimentalConfig_UpdateConfigH\x00\x12\x61\n#pronunciations_create_pronunciation\x18! \x01(\x0b\x32\x32.pronunciations.Pronunciations_CreatePronunciationH\x00\x12\x61\n#pronunciations_update_pronunciation\x18\" \x01(\x0b\x32\x32.pronunciations.Pronunciations_UpdatePronunciationH\x00\x12\x61\n#pronunciations_delete_pronunciation\x18# \x01(\x0b\x32\x32.pronunciations.Pronunciations_DeletePronunciationH\x00\x12\x66\n%pronunciations_reorder_pronunciations\x18\xed\x02 \x01(\x0b\x32\x34.pronunciations.Pronunciations_ReorderPronunciationsH\x00\x12r\n\x1d\x63reate_transcript_corrections\x18% \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_CreateTranscriptCorrectionsH\x00\x12r\n\x1dupdate_transcript_corrections\x18& \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_UpdateTranscriptCorrectionsH\x00\x12r\n\x1d\x64\x65lete_transcript_corrections\x18\' \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_DeleteTranscriptCorrectionsH\x00\x12\x39\n\x0fupdate_greeting\x18( \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreetingH\x00\x12\x42\n\x12update_personality\x18) \x01(\x0b\x32$.agent.Personality_UpdatePersonalityH\x00\x12-\n\x0bupdate_role\x18* \x01(\x0b\x32\x16.agent.Role_UpdateRoleH\x00\x12U\n\x19update_disclaimer_message\x18+ \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessageH\x00\x12\x30\n\x0cupdate_rules\x18, \x01(\x0b\x32\x18.agent.Rules_UpdateRulesH\x00\x12R\n\x18update_language_behavior\x18G \x01(\x0b\x32..agent.LanguageBehavior_UpdateLanguageBehaviorH\x00\x12=\n\x0f\x63reate_function\x18- \x01(\x0b\x32\".functions.Function_CreateFunctionH\x00\x12=\n\x0fupdate_function\x18\x30 \x01(\x0b\x32\".functions.Function_UpdateFunctionH\x00\x12=\n\x0f\x64\x65lete_function\x18\x31 \x01(\x0b\x32\".functions.Function_DeleteFunctionH\x00\x12J\n\x16update_latency_control\x18; \x01(\x0b\x32(.functions.Function_UpdateLatencyControlH\x00\x12\x45\n\x15\x63reate_start_function\x18< \x01(\x0b\x32$.start_function.StartFunction_CreateH\x00\x12\x45\n\x15update_start_function\x18= \x01(\x0b\x32$.start_function.StartFunction_UpdateH\x00\x12\x45\n\x15\x64\x65lete_start_function\x18\x41 \x01(\x0b\x32$.start_function.StartFunction_DeleteH\x00\x12?\n\x13\x63reate_end_function\x18> \x01(\x0b\x32 .end_function.EndFunction_CreateH\x00\x12?\n\x13update_end_function\x18? \x01(\x0b\x32 .end_function.EndFunction_UpdateH\x00\x12?\n\x13\x64\x65lete_end_function\x18\x42 \x01(\x0b\x32 .end_function.EndFunction_DeleteH\x00\x12Z\n\x19\x63reate_keyphrase_boosting\x18s \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_CreateKeyphraseH\x00\x12Z\n\x19update_keyphrase_boosting\x18t \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_UpdateKeyphraseH\x00\x12Z\n\x19\x64\x65lete_keyphrase_boosting\x18u \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_DeleteKeyphraseH\x00\x12;\n\x15voice_add_agent_voice\x18\x33 \x01(\x0b\x32\x1a.voice.Voice_AddAgentVoiceH\x00\x12\x41\n\x18voice_delete_agent_voice\x18\x34 \x01(\x0b\x32\x1d.voice.Voice_DeleteAgentVoiceH\x00\x12\x41\n\x18voice_update_agent_voice\x18\x35 \x01(\x0b\x32\x1d.voice.Voice_UpdateAgentVoiceH\x00\x12R\n!voice_create_agent_voice_settings\x18\x36 \x01(\x0b\x32%.voice.Voice_CreateAgentVoiceSettingsH\x00\x12R\n!voice_update_agent_voice_settings\x18\x37 \x01(\x0b\x32%.voice.Voice_UpdateAgentVoiceSettingsH\x00\x12K\n\x1dvoice_update_disclaimer_voice\x18\x38 \x01(\x0b\x32\".voice.Voice_UpdateDisclaimerVoiceH\x00\x12\\\n&voice_create_disclaimer_voice_settings\x18\x39 \x01(\x0b\x32*.voice.Voice_CreateDisclaimerVoiceSettingsH\x00\x12\\\n&voice_update_disclaimer_voice_settings\x18: \x01(\x0b\x32*.voice.Voice_UpdateDisclaimerVoiceSettingsH\x00\x12\x41\n\x18voice_add_favorite_voice\x18x \x01(\x0b\x32\x1d.voice.Voice_AddFavoriteVoiceH\x00\x12G\n\x1bvoice_remove_favorite_voice\x18y \x01(\x0b\x32 .voice.Voice_RemoveFavoriteVoiceH\x00\x12\x34\n\x14\x62ranch_trigger_merge\x18\r \x01(\x0b\x32\x14.Branch_TriggerMergeH\x00\x12)\n\x0e\x62ranch_created\x18\x0e \x01(\x0b\x32\x0f.Branch_CreatedH\x00\x12\'\n\rbranch_merged\x18\x0f \x01(\x0b\x32\x0e.Branch_MergedH\x00\x12)\n\x0e\x62ranch_deleted\x18/ \x01(\x0b\x32\x0f.Branch_DeletedH\x00\x12+\n\x0fproject_created\x18\x10 \x01(\x0b\x32\x10.Project_CreatedH\x00\x12\x41\n\x1bproject_loaded_from_jupiter\x18\x11 \x01(\x0b\x32\x1a.Project_LoadedFromJupiterH\x00\x12\x34\n\x14\x64\x65ployment_completed\x18$ \x01(\x0b\x32\x14.DeploymentCompletedH\x00\x12\x32\n\x13\x64\x65ployment_rollback\x18@ \x01(\x0b\x32\x13.DeploymentRollbackH\x00\x12\x30\n\rentity_create\x18\x43 \x01(\x0b\x32\x17.entities.Entity_CreateH\x00\x12\x30\n\rentity_update\x18\x44 \x01(\x0b\x32\x17.entities.Entity_UpdateH\x00\x12\x30\n\rentity_delete\x18\x45 \x01(\x0b\x32\x17.entities.Entity_DeleteH\x00\x12\x36\n\x0fvariable_create\x18\xe1\x01 \x01(\x0b\x32\x1a.variables.Variable_CreateH\x00\x12\x36\n\x0fvariable_update\x18\xe2\x01 \x01(\x0b\x32\x1a.variables.Variable_UpdateH\x00\x12\x36\n\x0fvariable_delete\x18\xe3\x01 \x01(\x0b\x32\x1a.variables.Variable_DeleteH\x00\x12\x45\n\x1d\x66unction_deployment_completed\x18\x46 \x01(\x0b\x32\x1c.FunctionDeploymentCompletedH\x00\x12J\n\x16\x63reate_api_integration\x18\xac\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_CreateH\x00\x12J\n\x16update_api_integration\x18\xad\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_UpdateH\x00\x12J\n\x16\x64\x65lete_api_integration\x18\xae\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_DeleteH\x00\x12W\n\x1dupdate_api_integration_config\x18\xaf\x02 \x01(\x0b\x32-.api_integrations.ApiIntegrationConfig_UpdateH\x00\x12]\n create_api_integration_operation\x18\xb0\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_CreateH\x00\x12]\n update_api_integration_operation\x18\xb1\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_UpdateH\x00\x12]\n delete_api_integration_operation\x18\xb2\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_DeleteH\x00\x12K\n\x12\x63reate_translation\x18\xdf\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_CreateH\x00\x12K\n\x12update_translation\x18\xe0\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_UpdateH\x00\x12K\n\x12\x64\x65lete_translation\x18\xe1\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_DeleteH\x00\x12V\n!voice_channel_update_asr_settings\x18\xe6\x02 \x01(\x0b\x32(.channels.VoiceChannel_UpdateASRSettingsH\x00\x12S\n\x1fvoice_channel_update_disclaimer\x18\xe7\x02 \x01(\x0b\x32\'.channels.VoiceChannel_UpdateDisclaimerH\x00\x12\x44\n\x17\x63hannel_update_greeting\x18\xf8\x02 \x01(\x0b\x32 .channels.Channel_UpdateGreetingH\x00\x12K\n\x1b\x63hannel_update_style_prompt\x18\xf9\x02 \x01(\x0b\x32#.channels.Channel_UpdateStylePromptH\x00\x12O\n\x1d\x63hannel_update_safety_filters\x18\xfa\x02 \x01(\x0b\x32%.channels.Channel_UpdateSafetyFiltersH\x00\x12K\n\x1b\x63hannel_update_llm_settings\x18\xfb\x02 \x01(\x0b\x32#.channels.Channel_UpdateLLMSettingsH\x00\x12@\n\x15\x63hannel_update_status\x18\xfc\x02 \x01(\x0b\x32\x1e.channels.Channel_UpdateStatusH\x00\x12\x36\n\x12\x63sat_update_config\x18\xf2\x02 \x01(\x0b\x32\x17.csat.CSAT_UpdateConfigH\x00\x12\x41\n\x13\x63onnect_integration\x18\xf3\x02 \x01(\x0b\x32!.integrations.Integration_ConnectH\x00\x12?\n\x12\x65nable_integration\x18\xf4\x02 \x01(\x0b\x32 .integrations.Integration_EnableH\x00\x12\x41\n\x13\x64isable_integration\x18\xf7\x02 \x01(\x0b\x32!.integrations.Integration_DisableH\x00\x12R\n\x1cupdate_integration_functions\x18\xf5\x02 \x01(\x0b\x32).integrations.Integration_UpdateFunctionsH\x00\x12G\n\x16\x64isconnect_integration\x18\xf6\x02 \x01(\x0b\x32$.integrations.Integration_DisconnectH\x00\x42\t\n\x07payloadJ\x06\x08\xe2\x02\x10\xe3\x02J\x06\x08\xe3\x02\x10\xe4\x02J\x06\x08\xe4\x02\x10\xe5\x02J\x06\x08\xe5\x02\x10\xe6\x02J\x06\x08\xe8\x02\x10\xe9\x02J\x06\x08\xe9\x02\x10\xea\x02J\x06\x08\xea\x02\x10\xeb\x02J\x06\x08\xeb\x02\x10\xec\x02J\x06\x08\xec\x02\x10\xed\x02\"$\n\nEventBatch\x12\x16\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x06.Event\"k\n\rSetProjection\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x12\n\nprojection\x18\x02 \x01(\x0c\x12\x34\n\x10server_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1e\n\x0bSocketError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xa9\x01\n\x08\x45nvelope\x12\"\n\x0b\x65vent_batch\x18\x01 \x01(\x0b\x32\x0b.EventBatchH\x00\x12(\n\x0eset_projection\x18\x02 \x01(\x0b\x32\x0e.SetProjectionH\x00\x12%\n\x0cnotification\x18\x03 \x01(\x0b\x32\r.NotificationH\x00\x12\x1d\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x0c.SocketErrorH\x00\x42\t\n\x07message\"\xdc\x01\n\x0cNotification\x12\x0c\n\x04type\x18\x01 \x01(\t\x12)\n\x0e\x62ranch_created\x18\x02 \x01(\x0b\x32\x0f.Branch_CreatedH\x00\x12\'\n\rbranch_merged\x18\x03 \x01(\x0b\x32\x0e.Branch_MergedH\x00\x12)\n\x0e\x62ranch_deleted\x18\x04 \x01(\x0b\x32\x0f.Branch_DeletedH\x00\x12\x34\n\x14\x62ranch_trigger_merge\x18\x05 \x01(\x0b\x32\x14.Branch_TriggerMergeH\x00\x42\t\n\x07payload\"\x9aJ\n\x07\x43ommand\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1c\n\x08metadata\x18\xc8\x01 \x01(\x0b\x32\t.Metadata\x12\x12\n\ncommand_id\x18\x02 \x01(\t\x12\x41\n\x0c\x63reate_topic\x18\x03 \x01(\x0b\x32).knowledge_base.KnowledgeBase_CreateTopicH\x00\x12\x41\n\x0cupdate_topic\x18\x04 \x01(\x0b\x32).knowledge_base.KnowledgeBase_UpdateTopicH\x00\x12\x41\n\x0c\x64\x65lete_topic\x18\x05 \x01(\x0b\x32).knowledge_base.KnowledgeBase_DeleteTopicH\x00\x12\x43\n\rimport_topics\x18v \x01(\x0b\x32*.knowledge_base.KnowledgeBase_ImportTopicsH\x00\x12N\n\x13toggle_topic_status\x18w \x01(\x0b\x32/.knowledge_base.KnowledgeBase_ToggleTopicStatusH\x00\x12\x36\n\x13sms_create_template\x18\x06 \x01(\x0b\x32\x17.sms.SMS_CreateTemplateH\x00\x12\x36\n\x13sms_update_template\x18\x07 \x01(\x0b\x32\x17.sms.SMS_UpdateTemplateH\x00\x12\x36\n\x13sms_delete_template\x18\x08 \x01(\x0b\x32\x17.sms.SMS_DeleteTemplateH\x00\x12\x31\n\x0ehandoff_create\x18\t \x01(\x0b\x32\x17.handoff.Handoff_CreateH\x00\x12\x31\n\x0ehandoff_update\x18\n \x01(\x0b\x32\x17.handoff.Handoff_UpdateH\x00\x12\x31\n\x0ehandoff_delete\x18\x0b \x01(\x0b\x32\x17.handoff.Handoff_DeleteH\x00\x12:\n\x13handoff_set_default\x18\x1a \x01(\x0b\x32\x1b.handoff.Handoff_SetDefaultH\x00\x12M\n\x1dhandoff_reset_handoff_configs\x18/ \x01(\x0b\x32$.handoff.Handoff_ResetHandoffConfigsH\x00\x12\x44\n\x18variant_create_attribute\x18\x0c \x01(\x0b\x32 .variant.Variant_CreateAttributeH\x00\x12\x44\n\x18variant_update_attribute\x18\r \x01(\x0b\x32 .variant.Variant_UpdateAttributeH\x00\x12\x44\n\x18variant_delete_attribute\x18\x0e \x01(\x0b\x32 .variant.Variant_DeleteAttributeH\x00\x12@\n\x16variant_create_variant\x18\x0f \x01(\x0b\x32\x1e.variant.Variant_CreateVariantH\x00\x12@\n\x16variant_update_variant\x18\x10 \x01(\x0b\x32\x1e.variant.Variant_UpdateVariantH\x00\x12@\n\x16variant_delete_variant\x18\x11 \x01(\x0b\x32\x1e.variant.Variant_DeleteVariantH\x00\x12I\n\x1bvariant_set_default_variant\x18\x12 \x01(\x0b\x32\".variant.Variant_SetDefaultVariantH\x00\x12\x42\n\x17variant_import_variants\x18\x32 \x01(\x0b\x32\x1f.variant.Variant_ImportVariantsH\x00\x12\x41\n\x14stop_keywords_create\x18\x13 \x01(\x0b\x32!.stop_keywords.StopKeyword_CreateH\x00\x12\x41\n\x14stop_keywords_update\x18\x14 \x01(\x0b\x32!.stop_keywords.StopKeyword_UpdateH\x00\x12\x41\n\x14stop_keywords_delete\x18\x15 \x01(\x0b\x32!.stop_keywords.StopKeyword_DeleteH\x00\x12J\n\x13update_llm_settings\x18\x16 \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettingsH\x00\x12t\n\x1eupdate_content_filter_settings\x18\x17 \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettingsH\x00\x12J\n\x13update_asr_settings\x18\x18 \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettingsH\x00\x12M\n\x13update_tts_settings\x18\x19 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageB\x02\x18\x01H\x00\x12X\n!languages_update_default_language\x18\xe7\x01 \x01(\x0b\x32*.languages.Languages_UpdateDefaultLanguageH\x00\x12\x43\n\x16languages_add_language\x18\xe8\x01 \x01(\x0b\x32 .languages.Languages_AddLanguageH\x00\x12I\n\x19languages_delete_language\x18\xe9\x01 \x01(\x0b\x32#.languages.Languages_DeleteLanguageH\x00\x12\x61\n!experimental_config_update_config\x18\' \x01(\x0b\x32\x34.experimental_config.ExperimentalConfig_UpdateConfigH\x00\x12\x61\n#pronunciations_create_pronunciation\x18\x1b \x01(\x0b\x32\x32.pronunciations.Pronunciations_CreatePronunciationH\x00\x12\x61\n#pronunciations_update_pronunciation\x18\x1c \x01(\x0b\x32\x32.pronunciations.Pronunciations_UpdatePronunciationH\x00\x12\x61\n#pronunciations_delete_pronunciation\x18\x1d \x01(\x0b\x32\x32.pronunciations.Pronunciations_DeletePronunciationH\x00\x12\x65\n%pronunciations_reorder_pronunciations\x18< \x01(\x0b\x32\x34.pronunciations.Pronunciations_ReorderPronunciationsH\x00\x12r\n\x1d\x63reate_transcript_corrections\x18\x1e \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_CreateTranscriptCorrectionsH\x00\x12r\n\x1dupdate_transcript_corrections\x18\x1f \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_UpdateTranscriptCorrectionsH\x00\x12r\n\x1d\x64\x65lete_transcript_corrections\x18  \x01(\x0b\x32I.transcript_corrections.TranscriptCorrections_DeleteTranscriptCorrectionsH\x00\x12\x39\n\x0fupdate_greeting\x18! \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreetingH\x00\x12\x42\n\x12update_personality\x18\" \x01(\x0b\x32$.agent.Personality_UpdatePersonalityH\x00\x12-\n\x0bupdate_role\x18# \x01(\x0b\x32\x16.agent.Role_UpdateRoleH\x00\x12U\n\x19update_disclaimer_message\x18$ \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessageH\x00\x12\x30\n\x0cupdate_rules\x18% \x01(\x0b\x32\x18.agent.Rules_UpdateRulesH\x00\x12R\n\x18update_language_behavior\x18; \x01(\x0b\x32..agent.LanguageBehavior_UpdateLanguageBehaviorH\x00\x12=\n\x0f\x63reate_function\x18& \x01(\x0b\x32\".functions.Function_CreateFunctionH\x00\x12=\n\x0fupdate_function\x18( \x01(\x0b\x32\".functions.Function_UpdateFunctionH\x00\x12=\n\x0f\x64\x65lete_function\x18) \x01(\x0b\x32\".functions.Function_DeleteFunctionH\x00\x12J\n\x16update_latency_control\x18* \x01(\x0b\x32(.functions.Function_UpdateLatencyControlH\x00\x12\x45\n\x15\x63reate_start_function\x18+ \x01(\x0b\x32$.start_function.StartFunction_CreateH\x00\x12\x45\n\x15update_start_function\x18, \x01(\x0b\x32$.start_function.StartFunction_UpdateH\x00\x12\x45\n\x15\x64\x65lete_start_function\x18\x30 \x01(\x0b\x32$.start_function.StartFunction_DeleteH\x00\x12?\n\x13\x63reate_end_function\x18- \x01(\x0b\x32 .end_function.EndFunction_CreateH\x00\x12?\n\x13update_end_function\x18. \x01(\x0b\x32 .end_function.EndFunction_UpdateH\x00\x12?\n\x13\x64\x65lete_end_function\x18\x31 \x01(\x0b\x32 .end_function.EndFunction_DeleteH\x00\x12;\n\x15voice_add_agent_voice\x18\x33 \x01(\x0b\x32\x1a.voice.Voice_AddAgentVoiceH\x00\x12\x41\n\x18voice_delete_agent_voice\x18\x34 \x01(\x0b\x32\x1d.voice.Voice_DeleteAgentVoiceH\x00\x12\x41\n\x18voice_update_agent_voice\x18\x35 \x01(\x0b\x32\x1d.voice.Voice_UpdateAgentVoiceH\x00\x12R\n!voice_create_agent_voice_settings\x18\x36 \x01(\x0b\x32%.voice.Voice_CreateAgentVoiceSettingsH\x00\x12R\n!voice_update_agent_voice_settings\x18\x37 \x01(\x0b\x32%.voice.Voice_UpdateAgentVoiceSettingsH\x00\x12K\n\x1dvoice_update_disclaimer_voice\x18\x38 \x01(\x0b\x32\".voice.Voice_UpdateDisclaimerVoiceH\x00\x12\\\n&voice_create_disclaimer_voice_settings\x18\x39 \x01(\x0b\x32*.voice.Voice_CreateDisclaimerVoiceSettingsH\x00\x12\\\n&voice_update_disclaimer_voice_settings\x18: \x01(\x0b\x32*.voice.Voice_UpdateDisclaimerVoiceSettingsH\x00\x12\x41\n\x18voice_add_favorite_voice\x18x \x01(\x0b\x32\x1d.voice.Voice_AddFavoriteVoiceH\x00\x12G\n\x1bvoice_remove_favorite_voice\x18y \x01(\x0b\x32 .voice.Voice_RemoveFavoriteVoiceH\x00\x12\x31\n\rentity_create\x18\xa5\x01 \x01(\x0b\x32\x17.entities.Entity_CreateH\x00\x12\x31\n\rentity_update\x18\xa6\x01 \x01(\x0b\x32\x17.entities.Entity_UpdateH\x00\x12\x31\n\rentity_delete\x18\xa7\x01 \x01(\x0b\x32\x17.entities.Entity_DeleteH\x00\x12\x36\n\x0fvariable_create\x18\xa8\x01 \x01(\x0b\x32\x1a.variables.Variable_CreateH\x00\x12\x36\n\x0fvariable_update\x18\xa9\x01 \x01(\x0b\x32\x1a.variables.Variable_UpdateH\x00\x12\x36\n\x0fvariable_delete\x18\xaa\x01 \x01(\x0b\x32\x1a.variables.Variable_DeleteH\x00\x12\x32\n\x10\x63reate_flow_step\x18\x64 \x01(\x0b\x32\x16.flows.Flow_CreateStepH\x00\x12\x32\n\x10update_flow_step\x18\x65 \x01(\x0b\x32\x16.flows.Flow_UpdateStepH\x00\x12\x32\n\x10\x64\x65lete_flow_step\x18\x66 \x01(\x0b\x32\x16.flows.Flow_DeleteStepH\x00\x12\x43\n\x19update_flow_step_position\x18g \x01(\x0b\x32\x1e.flows.Flow_UpdateStepPositionH\x00\x12\x45\n\x1aupdate_flow_step_positions\x18h \x01(\x0b\x32\x1f.flows.Flow_UpdateStepPositionsH\x00\x12H\n\x1cupdate_flow_step_dtmf_config\x18i \x01(\x0b\x32 .flows.Flow_UpdateStepDtmfConfigH\x00\x12\x46\n\x1bupdate_flow_step_asr_config\x18j \x01(\x0b\x32\x1f.flows.Flow_UpdateStepAsrConfigH\x00\x12O\n\x1f\x63reate_flow_transition_function\x18k \x01(\x0b\x32$.flows.Flow_CreateTransitionFunctionH\x00\x12O\n\x1fupdate_flow_transition_function\x18l \x01(\x0b\x32$.flows.Flow_UpdateTransitionFunctionH\x00\x12O\n\x1f\x64\x65lete_flow_transition_function\x18m \x01(\x0b\x32$.flows.Flow_DeleteTransitionFunctionH\x00\x12-\n\x0b\x64\x65lete_flow\x18n \x01(\x0b\x32\x16.flows.Flow_DeleteFlowH\x00\x12-\n\x0b\x63reate_flow\x18o \x01(\x0b\x32\x16.flows.Flow_CreateFlowH\x00\x12-\n\x0bimport_flow\x18p \x01(\x0b\x32\x16.flows.Flow_ImportFlowH\x00\x12-\n\x0bupdate_flow\x18q \x01(\x0b\x32\x16.flows.Flow_UpdateFlowH\x00\x12m\n/update_flow_transition_function_latency_control\x18r \x01(\x0b\x32\x32.flows.Flow_UpdateTransitionFunctionLatencyControlH\x00\x12\x37\n\x13\x63reate_no_code_step\x18\xd6\x01 \x01(\x0b\x32\x17.flows.CreateNoCodeStepH\x00\x12\x37\n\x13update_no_code_step\x18\xd7\x01 \x01(\x0b\x32\x17.flows.UpdateNoCodeStepH\x00\x12\x37\n\x13\x64\x65lete_no_code_step\x18\xd8\x01 \x01(\x0b\x32\x17.flows.DeleteNoCodeStepH\x00\x12H\n\x1cupdate_no_code_step_position\x18\xd9\x01 \x01(\x0b\x32\x1f.flows.UpdateNoCodeStepPositionH\x00\x12\x41\n\x18\x63reate_no_code_condition\x18\xda\x01 \x01(\x0b\x32\x1c.flows.CreateNoCodeConditionH\x00\x12\x41\n\x18\x64\x65lete_no_code_condition\x18\xdb\x01 \x01(\x0b\x32\x1c.flows.DeleteNoCodeConditionH\x00\x12\x41\n\x18update_no_code_condition\x18\xdc\x01 \x01(\x0b\x32\x1c.flows.UpdateNoCodeConditionH\x00\x12R\n!update_no_code_condition_position\x18\xdd\x01 \x01(\x0b\x32$.flows.UpdateNoCodeConditionPositionH\x00\x12\x64\n+update_no_code_condition_exit_flow_position\x18\xde\x01 \x01(\x0b\x32,.flows.UpdateNoCodeConditionExitFlowPositionH\x00\x12\x38\n\x13move_flow_component\x18\xdf\x01 \x01(\x0b\x32\x18.flows.MoveFlowComponentH\x00\x12:\n\x14move_flow_components\x18\xe0\x01 \x01(\x0b\x32\x19.flows.MoveFlowComponentsH\x00\x12)\n\x0b\x63reate_step\x18\xb3\x02 \x01(\x0b\x32\x11.flows.CreateStepH\x00\x12)\n\x0bupdate_step\x18\xb4\x02 \x01(\x0b\x32\x11.flows.UpdateStepH\x00\x12)\n\x0b\x64\x65lete_step\x18\xb5\x02 \x01(\x0b\x32\x11.flows.DeleteStepH\x00\x12<\n\x15\x63reate_step_condition\x18\xb6\x02 \x01(\x0b\x32\x1a.flows.CreateStepConditionH\x00\x12<\n\x15update_step_condition\x18\xb7\x02 \x01(\x0b\x32\x1a.flows.UpdateStepConditionH\x00\x12<\n\x15\x64\x65lete_step_condition\x18\xb8\x02 \x01(\x0b\x32\x1a.flows.DeleteStepConditionH\x00\x12M\n\x1eupdate_step_condition_position\x18\xb9\x02 \x01(\x0b\x32\".flows.UpdateStepConditionPositionH\x00\x12Z\n\x19\x63reate_keyphrase_boosting\x18s \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_CreateKeyphraseH\x00\x12Z\n\x19update_keyphrase_boosting\x18t \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_UpdateKeyphraseH\x00\x12Z\n\x19\x64\x65lete_keyphrase_boosting\x18u \x01(\x0b\x32\x35.keyphrase_boosting.KeyphraseBoosting_DeleteKeyphraseH\x00\x12J\n\x16\x63reate_api_integration\x18\xac\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_CreateH\x00\x12J\n\x16update_api_integration\x18\xad\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_UpdateH\x00\x12J\n\x16\x64\x65lete_api_integration\x18\xae\x02 \x01(\x0b\x32\'.api_integrations.ApiIntegration_DeleteH\x00\x12W\n\x1dupdate_api_integration_config\x18\xaf\x02 \x01(\x0b\x32-.api_integrations.ApiIntegrationConfig_UpdateH\x00\x12]\n create_api_integration_operation\x18\xb0\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_CreateH\x00\x12]\n update_api_integration_operation\x18\xb1\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_UpdateH\x00\x12]\n delete_api_integration_operation\x18\xb2\x02 \x01(\x0b\x32\x30.api_integrations.ApiIntegrationOperation_DeleteH\x00\x12K\n\x12\x63reate_translation\x18\xdf\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_CreateH\x00\x12K\n\x12update_translation\x18\xe0\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_UpdateH\x00\x12K\n\x12\x64\x65lete_translation\x18\xe1\x02 \x01(\x0b\x32,.translations.LanguageHubTranslations_DeleteH\x00\x12V\n!voice_channel_update_asr_settings\x18\xe6\x02 \x01(\x0b\x32(.channels.VoiceChannel_UpdateASRSettingsH\x00\x12S\n\x1fvoice_channel_update_disclaimer\x18\xe7\x02 \x01(\x0b\x32\'.channels.VoiceChannel_UpdateDisclaimerH\x00\x12\x44\n\x17\x63hannel_update_greeting\x18\xf8\x02 \x01(\x0b\x32 .channels.Channel_UpdateGreetingH\x00\x12K\n\x1b\x63hannel_update_style_prompt\x18\xf9\x02 \x01(\x0b\x32#.channels.Channel_UpdateStylePromptH\x00\x12O\n\x1d\x63hannel_update_safety_filters\x18\xfa\x02 \x01(\x0b\x32%.channels.Channel_UpdateSafetyFiltersH\x00\x12K\n\x1b\x63hannel_update_llm_settings\x18\xfb\x02 \x01(\x0b\x32#.channels.Channel_UpdateLLMSettingsH\x00\x12@\n\x15\x63hannel_update_status\x18\xfc\x02 \x01(\x0b\x32\x1e.channels.Channel_UpdateStatusH\x00\x12\x36\n\x12\x63sat_update_config\x18\xf2\x02 \x01(\x0b\x32\x17.csat.CSAT_UpdateConfigH\x00\x12\x41\n\x13\x63onnect_integration\x18\xf3\x02 \x01(\x0b\x32!.integrations.Integration_ConnectH\x00\x12?\n\x12\x65nable_integration\x18\xf4\x02 \x01(\x0b\x32 .integrations.Integration_EnableH\x00\x12\x41\n\x13\x64isable_integration\x18\xf7\x02 \x01(\x0b\x32!.integrations.Integration_DisableH\x00\x12R\n\x1cupdate_integration_functions\x18\xf5\x02 \x01(\x0b\x32).integrations.Integration_UpdateFunctionsH\x00\x12G\n\x16\x64isconnect_integration\x18\xf6\x02 \x01(\x0b\x32$.integrations.Integration_DisconnectH\x00\x42\t\n\x07payloadJ\x06\x08\xe2\x02\x10\xe3\x02J\x06\x08\xe3\x02\x10\xe4\x02J\x06\x08\xe4\x02\x10\xe5\x02J\x06\x08\xe5\x02\x10\xe6\x02J\x06\x08\xe8\x02\x10\xe9\x02J\x06\x08\xe9\x02\x10\xea\x02J\x06\x08\xea\x02\x10\xeb\x02J\x06\x08\xeb\x02\x10\xec\x02J\x06\x08\xec\x02\x10\xed\x02\"G\n\x0c\x43ommandBatch\x12\x1b\n\x13last_known_sequence\x18\x01 \x01(\x04\x12\x1a\n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x08.Command\"v\n\x0e\x42ranch_Created\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"r\n\x13\x42ranch_TriggerMerge\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x32\n\x0euser_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0ctriggered_by\x18\x03 \x01(\t\"\x80\x01\n\x12\x43onflictResolution\x12\x0c\n\x04path\x18\x01 \x03(\t\x12%\n\x08strategy\x18\x02 \x01(\x0e\x32\x13.ResolutionStrategy\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xbb\x01\n\rBranch_Merged\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12-\n\tmerged_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmerged_by\x18\x03 \x01(\t\x12\x15\n\rmain_sequence\x18\x04 \x01(\x04\x12\x14\n\x0csnapshot_key\x18\x05 \x01(\t\x12(\n\x0bresolutions\x18\x06 \x03(\x0b\x32\x13.ConflictResolution\"g\n\x0e\x42ranch_Deleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12.\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ndeleted_by\x18\x03 \x01(\t\"y\n\x0fProject_Created\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"\x92\x01\n\x19Project_LoadedFromJupiter\x12-\n\tloaded_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61rtifact_version\x18\x02 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x03 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x04 \x01(\t\"\xe2\x01\n\x13\x44\x65ploymentCompleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x12\n\nclient_env\x18\x02 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x03 \x01(\t\x12\x18\n\x10\x61rtifact_version\x18\x04 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x05 \x01(\t\x12#\n\x1b\x66unction_deployment_version\x18\x06 \x01(\t\x12!\n\x19lambda_deployment_version\x18\x08 \x01(\t\x12\x14\n\x0cversion_hash\x18\x07 \x01(\t\"\xaa\x01\n\x12\x44\x65ploymentRollback\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x03 \x01(\t\x12\x18\n\x10\x61rtifact_version\x18\x04 \x01(\t\x12\x16\n\x0erag_kb_version\x18\x05 \x01(\t\x12#\n\x1b\x66unction_deployment_version\x18\x06 \x01(\t\x12\x14\n\x0cversion_hash\x18\x07 \x01(\t\"(\n\x10LoadedFromBundle\x12\x14\n\x0csnapshot_key\x18\x01 \x01(\t\"\x89\x01\n\x1b\x46unctionDeploymentCompleted\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x14\n\x0csnapshot_key\x18\x02 \x01(\t\x12\x1e\n\x16\x66unction_deployment_id\x18\x03 \x01(\t\x12!\n\x19lambda_deployment_version\x18\x04 \x01(\t*4\n\x12ResolutionStrategy\x12\n\n\x06theirs\x10\x00\x12\x08\n\x04ours\x10\x01\x12\x08\n\x04\x62\x61se\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EVENT'].fields_by_name['update_tts_settings']._options = None
  _globals['_EVENT'].fields_by_name['update_tts_settings']._serialized_options = b'\030\001'
  _globals['_COMMAND'].fields_by_name['update_tts_settings']._options = None
  _globals['_COMMAND'].fields_by_name['update_tts_settings']._serialized_options = b'\030\001'
  _globals['_RESOLUTIONSTRATEGY']._serialized_start=22361
  _globals['_RESOLUTIONSTRATEGY']._serialized_end=22413
  _globals['_METADATA']._serialized_start=590
  _globals['_METADATA']._serialized_end=668
  _globals['_EVENT']._serialized_start=671
  _globals['_EVENT']._serialized_end=10693
  _globals['_EVENTBATCH']._serialized_start=10695
  _globals['_EVENTBATCH']._serialized_end=10731
  _globals['_SETPROJECTION']._serialized_start=10733
  _globals['_SETPROJECTION']._serialized_end=10840
  _globals['_SOCKETERROR']._serialized_start=10842
  _globals['_SOCKETERROR']._serialized_end=10872
  _globals['_ENVELOPE']._serialized_start=10875
  _globals['_ENVELOPE']._serialized_end=11044
  _globals['_NOTIFICATION']._serialized_start=11047
  _globals['_NOTIFICATION']._serialized_end=11267
  _globals['_COMMAND']._serialized_start=11270
  _globals['_COMMAND']._serialized_end=20768
  _globals['_COMMANDBATCH']._serialized_start=20770
  _globals['_COMMANDBATCH']._serialized_end=20841
  _globals['_BRANCH_CREATED']._serialized_start=20843
  _globals['_BRANCH_CREATED']._serialized_end=20961
  _globals['_BRANCH_TRIGGERMERGE']._serialized_start=20963
  _globals['_BRANCH_TRIGGERMERGE']._serialized_end=21077
  _globals['_CONFLICTRESOLUTION']._serialized_start=21080
  _globals['_CONFLICTRESOLUTION']._serialized_end=21208
  _globals['_BRANCH_MERGED']._serialized_start=21211
  _globals['_BRANCH_MERGED']._serialized_end=21398
  _globals['_BRANCH_DELETED']._serialized_start=21400
  _globals['_BRANCH_DELETED']._serialized_end=21503
  _globals['_PROJECT_CREATED']._serialized_start=21505
  _globals['_PROJECT_CREATED']._serialized_end=21626
  _globals['_PROJECT_LOADEDFROMJUPITER']._serialized_start=21629
  _globals['_PROJECT_LOADEDFROMJUPITER']._serialized_end=21775
  _globals['_DEPLOYMENTCOMPLETED']._serialized_start=21778
  _globals['_DEPLOYMENTCOMPLETED']._serialized_end=22004
  _globals['_DEPLOYMENTROLLBACK']._serialized_start=22007
  _globals['_DEPLOYMENTROLLBACK']._serialized_end=22177
  _globals['_LOADEDFROMBUNDLE']._serialized_start=22179
  _globals['_LOADEDFROMBUNDLE']._serialized_end=22219
  _globals['_FUNCTIONDEPLOYMENTCOMPLETED']._serialized_start=22222
  _globals['_FUNCTIONDEPLOYMENTCOMPLETED']._serialized_end=22359
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Language(_message.Message):
    __slots__ = ("code", "created_at", "created_by", "updated_at", "updated_by")
    CODE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    code: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    updated_at: _timestamp_pb2.Timestamp
    updated_by: str
    def __init__(self, code: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ...) -> None: ...

class Languages(_message.Message):
    __slots__ = ("default_language_code", "updated_by", "updated_at", "additional_languages")
    DEFAULT_LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    default_language_code: str
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    additional_languages: _containers.RepeatedCompositeFieldContainer[Language]
    def __init__(self, default_language_code: _Optional[str] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., additional_languages: _Optional[_Iterable[_Union[Language, _Mapping]]] = ...) -> None: ...

class Languages_UpdateDefaultLanguage(_message.Message):
    __slots__ = ("language_code",)
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    language_code: str
    def __init__(self, language_code: _Optional[str] = ...) -> None: ...

class Languages_AddLanguage(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class Languages_DeleteLanguage(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TranscriptCorrections(_message.Message):
    __slots__ = ("corrections",)
    CORRECTIONS_FIELD_NUMBER: _ClassVar[int]
    corrections: _containers.RepeatedCompositeFieldContainer[TranscriptCorrection]
    def __init__(self, corrections: _Optional[_Iterable[_Union[TranscriptCorrection, _Mapping]]] = ...) -> None: ...

class TranscriptCorrection(_message.Message):
    __slots__ = ("id", "name", "description", "regular_expressions", "created_by", "created_at", "updated_by", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REGULAR_EXPRESSIONS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    regular_expressions: _containers.RepeatedCompositeFieldContainer[RegularExpression]
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_by: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., regular_expressions: _Optional[_Iterable[_Union[RegularExpression, _Mapping]]] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RegularExpression(_message.Message):
    __slots__ = ("id", "regular_expression", "replacement", "replacement_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    REGULAR_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    regular_expression: str
    replacement: str
    replacement_type: str
    def __init__(self, id: _Optional[str] = ..., regular_expression: _Optional[str] = ..., replacement: _Optional[str] = ..., replacement_type: _Optional[str] = ...) -> None: ...

class TranscriptCorrections_CreateTranscriptCorrections(_message.Message):
    __slots__ = ("id", "name", "description", "regular_expressions")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REGULAR_EXPRESSIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    regular_expressions: _containers.RepeatedCompositeFieldContainer[RegularExpression]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., regular_expressions: _Optional[_Iterable[_Union[RegularExpression, _Mapping]]] = ...) -> None: ...

class TranscriptCorrections_UpdateTranscriptCorrections(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: TranscriptCorrectionsUpdateData
    def __init__(self, data: _Optional[_Union[TranscriptCorrectionsUpdateData, _Mapping]] = ...) -> None: ...

class TranscriptCorrectionsUpdateData(_message.Message):
    __slots__ = ("corrections",)
    CORRECTIONS_FIELD_NUMBER: _ClassVar[int]
    corrections: _containers.RepeatedCompositeFieldContainer[TranscriptCorrection]
    def __init__(self, corrections: _Optional[_Iterable[_Union[TranscriptCorrection, _Mapping]]] = ...) -> None: ...

class TranscriptCorrections_DeleteTranscriptCorrections(_message.Message):
    __slots__ = ("transcript_corrections_id",)
    TRANSCRIPT_CORRECTIONS_ID_FIELD_NUMBER: _ClassVar[int]
    transcript_corrections_id: str
    def __init__(self, transcript_corrections_id: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TTSRule(_message.Message):
    __slots__ = ("id", "regex", "replacement", "case_sensitive", "created_at", "created_by", "updated_at", "updated_by", "language_code", "description", "position", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    REGEX_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    regex: str
    replacement: str
    case_sensitive: bool
    created_at: str
    created_by: str
    updated_at: str
    updated_by: str
    language_code: str
    description: str
    position: int
    name: str
    def __init__(self, id: _Optional[str] = ..., regex: _Optional[str] = ..., replacement: _Optional[str] = ..., case_sensitive: bool = ..., created_at: _Optional[str] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[str] = ..., updated_by: _Optional[str] = ..., language_code: _Optional[str] = ..., description: _Optional[str] = ..., position: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...

class Pronunciations(_message.Message):
    __slots__ = ("pronunciations",)
    PRONUNCIATIONS_FIELD_NUMBER: _ClassVar[int]
    pronunciations: _containers.RepeatedCompositeFieldContainer[TTSRule]
    def __init__(self, pronunciations: _Optional[_Iterable[_Union[TTSRule, _Mapping]]] = ...) -> None: ...

class Pronunciations_CreatePronunciation(_message.Message):
    __slots__ = ("id", "regex", "replacement", "case_sensitive", "language_code", "description", "position", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    REGEX_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    regex: str
    replacement: str
    case_sensitive: bool
    language_code: str
    description: str
    position: int
    name: str
    def __init__(self, id: _Optional[str] = ..., regex: _Optional[str] = ..., replacement: _Optional[str] = ..., case_sensitive: bool = ..., language_code: _Optional[str] = ..., description: _Optional[str] = ..., position: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...

class Pronunciations_UpdatePronunciation(_message.Message):
    __slots__ = ("id", "regex", "replacement", "case_sensitive", "language_code", "description", "position", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    REGEX_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    regex: str
    replacement: str
    case_sensitive: bool
    language_code: str
    description: str
    position: int
    name: str
    def __init__(self, id: _Optional[str] = ..., regex: _Optional[str] = ..., replacement: _Optional[str] = ..., case_sensitive: bool = ..., language_code: _Optional[str] = ..., description: _Optional[str] = ..., position: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...

class Pronunciations_DeletePronunciation(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class Pronunciations_ReorderPronunciations(_message.Message):
    __slots__ = ("new_positions",)
    NEW_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    new_positions: _containers.RepeatedCompositeFieldContainer[PronunciationPositionUpdate]
    def __init__(self, new_positions: _Optional[_Iterable[_Union[PronunciationPositionUpdate, _Mapping]]] = ...) -> None: ...

class PronunciationPositionUpdate(_message.Message):
    __slots__ = ("id", "position")
    ID_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    id: str
    position: int
    def __init__(self, id: _Optional[str] = ..., position: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transcript_corrections.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctranscript_corrections.proto\x12\x16transcript_corrections\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\x15TranscriptCorrections\x12\x41\n\x0b\x63orrections\x18\x01 \x03(\x0b\x32,.transcript_corrections.TranscriptCorrection\"\x95\x02\n\x14TranscriptCorrection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x46\n\x13regular_expressions\x18\x04 \x03(\x0b\x32).transcript_corrections.RegularExpression\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"j\n\x11RegularExpression\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12regular_expression\x18\x02 \x01(\t\x12\x13\n\x0breplacement\x18\x03 \x01(\t\x12\x18\n\x10replacement_type\x18\x04 \x01(\t\"\xbf\x01\n1TranscriptCorrections_CreateTranscriptCorrections\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x46\n\x13regular_expressions\x18\x04 \x03(\x0b\x32).transcript_corrections.RegularExpressionB\x0e\n\x0c_description\"\x88\x01\n1TranscriptCorrections_UpdateTranscriptCorrections\x12J\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x37.transcript_corrections.TranscriptCorrectionsUpdateDataH\x00\x88\x01\x01\x42\x07\n\x05_data\"d\n\x1fTranscriptCorrectionsUpdateData\x12\x41\n\x0b\x63orrections\x18\x01 \x03(\x0b\x32,.transcript_corrections.TranscriptCorrection\"V\n1TranscriptCorrections_DeleteTranscriptCorrections\x12!\n\x19transcript_corrections_id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transcript_corrections_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRANSCRIPTCORRECTIONS']._serialized_start=89
  _globals['_TRANSCRIPTCORRECTIONS']._serialized_end=179
  _globals['_TRANSCRIPTCORRECTION']._serialized_start=182
  _globals['_TRANSCRIPTCORRECTION']._serialized_end=459
  _globals['_REGULAREXPRESSION']._serialized_start=461
  _globals['_REGULAREXPRESSION']._serialized_end=567
  _globals['_TRANSCRIPTCORRECTIONS_CREATETRANSCRIPTCORRECTIONS']._serialized_start=570
  _globals['_TRANSCRIPTCORRECTIONS_CREATETRANSCRIPTCORRECTIONS']._serialized_end=761
  _globals['_TRANSCRIPTCORRECTIONS_UPDATETRANSCRIPTCORRECTIONS']._serialized_start=764
  _globals['_TRANSCRIPTCORRECTIONS_UPDATETRANSCRIPTCORRECTIONS']._serialized_end=900
  _globals['_TRANSCRIPTCORRECTIONSUPDATEDATA']._serialized_start=902
  _globals['_TRANSCRIPTCORRECTIONSUPDATEDATA']._serialized_end=1002
  _globals['_TRANSCRIPTCORRECTIONS_DELETETRANSCRIPTCORRECTIONS']._serialized_start=1004
  _globals['_TRANSCRIPTCORRECTIONS_DELETETRANSCRIPTCORRECTIONS']._serialized_end=1090
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Asr(_message.Message):
    __slots__ = ("provider_id", "model_id", "language", "config")
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    provider_id: str
    model_id: str
    language: str
    config: _struct_pb2.Struct
    def __init__(self, provider_id: _Optional[str] = ..., model_id: _Optional[str] = ..., language: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: knowledge_base.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14knowledge_base.proto\x12\x0eknowledge_base\x1a\x1fgoogle/protobuf/timestamp.proto\"!\n\x0e\x45xampleQueries\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xd8\x04\n\x0fTopicReferences\x12\x35\n\x03sms\x18\x01 \x03(\x0b\x32(.knowledge_base.TopicReferences.SmsEntry\x12=\n\x07handoff\x18\x02 \x03(\x0b\x32,.knowledge_base.TopicReferences.HandoffEntry\x12\x43\n\nattributes\x18\x03 \x03(\x0b\x32/.knowledge_base.TopicReferences.AttributesEntry\x12N\n\x10global_functions\x18\x04 \x03(\x0b\x32\x34.knowledge_base.TopicReferences.GlobalFunctionsEntry\x12\x41\n\tvariables\x18\x05 \x03(\x0b\x32..knowledge_base.TopicReferences.VariablesEntry\x1a*\n\x08SmsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a.\n\x0cHandoffEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14GlobalFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\\\n\rKnowledgeBase\x12\x32\n\x06topics\x18\x01 \x03(\x0b\x32\".knowledge_base.KnowledgeBaseTopic\x12\x17\n\x0f\x65mbedding_model\x18\x02 \x01(\t\"\xec\x02\n\x12KnowledgeBaseTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63tions\x18\x04 \x01(\t\x12\x37\n\x0f\x65xample_queries\x18\x05 \x01(\x0b\x32\x1e.knowledge_base.ExampleQueries\x12\x33\n\nreferences\x18\x06 \x01(\x0b\x32\x1f.knowledge_base.TopicReferences\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\n \x01(\t\x12\x16\n\tis_active\x18\x0b \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_is_active\"\xeb\x01\n\x19KnowledgeBase_CreateTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63tions\x18\x04 \x01(\t\x12\x37\n\x0f\x65xample_queries\x18\x06 \x01(\x0b\x32\x1e.knowledge_base.ExampleQueries\x12\x33\n\nreferences\x18\x07 \x01(\x0b\x32\x1f.knowledge_base.TopicReferences\x12\x16\n\tis_active\x18\x08 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_is_active\"\xc8\x02\n\x19KnowledgeBase_UpdateTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x63ontent\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x61\x63tions\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\x0f\x65xample_queries\x18\x05 \x01(\x0b\x32\x1e.knowledge_base.ExampleQueriesH\x03\x88\x01\x01\x12\x38\n\nreferences\x18\x06 \x01(\x0b\x32\x1f.knowledge_base.TopicReferencesH\x04\x88\x01\x01\x12\x16\n\tis_active\x18\x07 \x01(\x08H\x05\x88\x01\x01\x42\x07\n\x05_nameB\n\n\x08_contentB\n\n\x08_actionsB\x12\n\x10_example_queriesB\r\n\x0b_referencesB\x0c\n\n_is_active\"\'\n\x19KnowledgeBase_DeleteTopic\x12\n\n\x02id\x18\x01 \x01(\t\"@\n\x1fKnowledgeBase_ToggleTopicStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tis_active\x18\x02 \x01(\x08\"\x89\x02\n\x1aKnowledgeBase_ImportTopics\x12:\n\x07\x63reated\x18\x01 \x03(\x0b\x32).knowledge_base.KnowledgeBase_CreateTopic\x12:\n\x07updated\x18\x02 \x03(\x0b\x32).knowledge_base.KnowledgeBase_UpdateTopic\x12\x0f\n\x07\x64\x65leted\x18\x03 \x03(\t\x12\x13\n\x06source\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x35\n\x08metadata\x18\x05 \x01(\x0b\x32\x1e.knowledge_base.ImportMetadataH\x01\x88\x01\x01\x42\t\n\x07_sourceB\x0b\n\t_metadata\"f\n\x0eImportMetadata\x12\x14\n\x0ctotal_topics\x18\x01 \x01(\x05\x12\x18\n\x10import_timestamp\x18\x02 \x01(\t\x12\x16\n\tfile_name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_file_nameb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'knowledge_base_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TOPICREFERENCES_SMSENTRY']._options = None
  _globals['_TOPICREFERENCES_SMSENTRY']._serialized_options = b'8\001'
  _globals['_TOPICREFERENCES_HANDOFFENTRY']._options = None
  _globals['_TOPICREFERENCES_HANDOFFENTRY']._serialized_options = b'8\001'
  _globals['_TOPICREFERENCES_ATTRIBUTESENTRY']._options = None
  _globals['_TOPICREFERENCES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_TOPICREFERENCES_GLOBALFUNCTIONSENTRY']._options = None
  _globals['_TOPICREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_TOPICREFERENCES_VARIABLESENTRY']._options = None
  _globals['_TOPICREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_EXAMPLEQUERIES']._serialized_start=73
  _globals['_EXAMPLEQUERIES']._serialized_end=106
  _globals['_TOPICREFERENCES']._serialized_start=109
  _globals['_TOPICREFERENCES']._serialized_end=709
  _globals['_TOPICREFERENCES_SMSENTRY']._serialized_start=462
  _globals['_TOPICREFERENCES_SMSENTRY']._serialized_end=504
  _globals['_TOPICREFERENCES_HANDOFFENTRY']._serialized_start=506
  _globals['_TOPICREFERENCES_HANDOFFENTRY']._serialized_end=552
  _globals['_TOPICREFERENCES_ATTRIBUTESENTRY']._serialized_start=554
  _globals['_TOPICREFERENCES_ATTRIBUTESENTRY']._serialized_end=603
  _globals['_TOPICREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_start=605
  _globals['_TOPICREFERENCES_GLOBALFUNCTIONSENTRY']._serialized_end=659
  _globals['_TOPICREFERENCES_VARIABLESENTRY']._serialized_start=661
  _globals['_TOPICREFERENCES_VARIABLESENTRY']._serialized_end=709
  _globals['_KNOWLEDGEBASE']._serialized_start=711
  _globals['_KNOWLEDGEBASE']._serialized_end=803
  _globals['_KNOWLEDGEBASETOPIC']._serialized_start=806
  _globals['_KNOWLEDGEBASETOPIC']._serialized_end=1170
  _globals['_KNOWLEDGEBASE_CREATETOPIC']._serialized_start=1173
  _globals['_KNOWLEDGEBASE_CREATETOPIC']._serialized_end=1408
  _globals['_KNOWLEDGEBASE_UPDATETOPIC']._serialized_start=1411
  _globals['_KNOWLEDGEBASE_UPDATETOPIC']._serialized_end=1739
  _globals['_KNOWLEDGEBASE_DELETETOPIC']._serialized_start=1741
  _globals['_KNOWLEDGEBASE_DELETETOPIC']._serialized_end=1780
  _globals['_KNOWLEDGEBASE_TOGGLETOPICSTATUS']._serialized_start=1782
  _globals['_KNOWLEDGEBASE_TOGGLETOPICSTATUS']._serialized_end=1846
  _globals['_KNOWLEDGEBASE_IMPORTTOPICS']._serialized_start=1849
  _globals['_KNOWLEDGEBASE_IMPORTTOPICS']._serialized_end=2114
  _globals['_IMPORTMETADATA']._serialized_start=2116
  _globals['_IMPORTMETADATA']._serialized_end=2218
# @@protoc_insertion_point(module_scope)



# Copyright PolyAI Limited
# flake8: noqa
# ruff: noqa
# type: ignore
from typing import Literal

__all__ = ["Attachment"]


class Attachment:
    """
    An attachment to an Agent Response.

    Attachments can be added to agent responses to provide additional context or information.
    They are currently only supported for WEBCHAT channels.
    """

    content_url: str
    content_type: Literal["image", "weblink", "unspecified"]
    title: str | None
    preview_image_url: str | None
    call_to_action: str | None

    def __init__(
        self,
        content_url: str,
        content_type: Literal["image", "weblink", "unspecified"],
        title: str | None = ...,
        preview_image_url: str | None = ...,
        call_to_action: str | None = ...,
    ) -> None: ...
    def to_dict(self) -> dict: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: end_function.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x65nd_function.proto\x12\x0c\x65nd_function\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0f\x66unctions.proto\"\x90\x01\n\x15\x45ndFunctionReferences\x12\x45\n\tvariables\x18\x01 \x03(\x0b\x32\x32.end_function.EndFunctionReferences.VariablesEntry\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xf9\x02\n\x0b\x45ndFunction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\n \x01(\t\x12\x10\n\x08\x61rchived\x18\x0b \x01(\x08\x12\x37\n\nreferences\x18\x0c \x01(\x0b\x32#.end_function.EndFunctionReferences\"\x9e\x02\n\x12\x45ndFunction_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x30\n\nparameters\x18\x04 \x03(\x0b\x32\x1c.functions.FunctionParameter\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12(\n\x06\x65rrors\x18\x06 \x03(\x0b\x32\x18.functions.FunctionError\x12\x15\n\x08\x61rchived\x18\x07 \x01(\x08H\x00\x88\x01\x01\x12<\n\nreferences\x18\x08 \x01(\x0b\x32#.end_function.EndFunctionReferencesH\x01\x88\x01\x01\x42\x0b\n\t_archivedB\r\n\x0b_references\" \n\x12\x45ndFunction_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"\xec\x01\n\x12\x45ndFunction_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x03 \x01(\tH\x01\x88\x01\x01\x12,\n\x06\x65rrors\x18\x04 \x01(\x0b\x32\x17.functions.ErrorsUpdateH\x02\x88\x01\x01\x12<\n\nreferences\x18\x05 \x01(\x0b\x32#.end_function.EndFunctionReferencesH\x03\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x07\n\x05_codeB\t\n\x07_errorsB\r\n\x0b_referencesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'end_function_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._options = None
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_ENDFUNCTIONREFERENCES']._serialized_start=87
  _globals['_ENDFUNCTIONREFERENCES']._serialized_end=231
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_start=183
  _globals['_ENDFUNCTIONREFERENCES_VARIABLESENTRY']._serialized_end=231
  _globals['_ENDFUNCTION']._serialized_start=234
  _globals['_ENDFUNCTION']._serialized_end=611
  _globals['_ENDFUNCTION_CREATE']._serialized_start=614
  _globals['_ENDFUNCTION_CREATE']._serialized_end=900
  _globals['_ENDFUNCTION_DELETE']._serialized_start=902
  _globals['_ENDFUNCTION_DELETE']._serialized_end=934
  _globals['_ENDFUNCTION_UPDATE']._serialized_start=937
  _globals['_ENDFUNCTION_UPDATE']._serialized_end=1173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: csat.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncsat.proto\x12\x04\x63sat\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x01\n\nCSATConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0flead_in_message\x18\x02 \x01(\t\x12\x17\n\x0fsurvey_question\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"\x99\x01\n\x11\x43SAT_UpdateConfig\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1c\n\x0flead_in_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fsurvey_question\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_enabledB\x12\n\x10_lead_in_messageB\x12\n\x10_survey_questionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'csat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CSATCONFIG']._serialized_start=54
  _globals['_CSATCONFIG']._serialized_end=309
  _globals['_CSAT_UPDATECONFIG']._serialized_start=312
  _globals['_CSAT_UPDATECONFIG']._serialized_end=465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: channels.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63hannels.proto\x12\x08\x63hannels\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\x14\x61gent_settings.proto\"\xb1\x01\n\x0bStylePrompt\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x33\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x17\n\nupdated_by\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_updated_atB\r\n\x0b_updated_by\"/\n\x1dStylePrompt_UpdateStylePrompt\x12\x0e\n\x06prompt\x18\x01 \x01(\t\"\xd8\x01\n\rChannelConfig\x12/\n\x0cllm_settings\x18\x01 \x01(\x0b\x32\x19.llm_settings.LLMSettings\x12+\n\x0cstyle_prompt\x18\x02 \x01(\x0b\x32\x15.channels.StylePrompt\x12!\n\x08greeting\x18\x03 \x01(\x0b\x32\x0f.agent.Greeting\x12\x46\n\x0esafety_filters\x18\x04 \x01(\x0b\x32..content_filter_settings.ContentFilterSettings\"\x96\x01\n\x0cVoiceChannel\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.channels.ChannelConfig\x12/\n\x0c\x61sr_settings\x18\x02 \x01(\x0b\x32\x19.asr_settings.ASRSettings\x12,\n\ndisclaimer\x18\x03 \x01(\x0b\x32\x18.agent.DisclaimerMessage\"b\n\x0eWebChatChannel\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.channels.ChannelConfig\x12\'\n\x06status\x18\x02 \x01(\x0e\x32\x17.channels.ChannelStatus\"]\n\x08\x43hannels\x12%\n\x05voice\x18\x01 \x01(\x0b\x32\x16.channels.VoiceChannel\x12*\n\x08web_chat\x18\x02 \x01(\x0b\x32\x18.channels.WebChatChannel\"w\n\x16\x43hannel_UpdateGreeting\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x30\n\x08greeting\x18\x02 \x01(\x0b\x32\x1e.agent.Greeting_UpdateGreeting\"\x87\x01\n\x19\x43hannel_UpdateStylePrompt\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12=\n\x0cstyle_prompt\x18\x02 \x01(\x0b\x32\'.channels.StylePrompt_UpdateStylePrompt\"\xae\x01\n\x1b\x43hannel_UpdateSafetyFilters\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x62\n\x0esafety_filters\x18\x02 \x01(\x0b\x32J.content_filter_settings.ContentFilterSettings_UpdateContentFilterSettings\"\x8b\x01\n\x19\x43hannel_UpdateLLMSettings\x12+\n\x0c\x63hannel_type\x18\x01 \x01(\x0e\x32\x15.channels.ChannelType\x12\x41\n\x0cllm_settings\x18\x02 \x01(\x0b\x32+.llm_settings.LLMSettings_UpdateLLMSettings\"b\n\x14\x43hannel_UpdateStatus\x12\x38\n\x07webchat\x18\x01 \x01(\x0b\x32%.channels.WebChatChannel_UpdateStatusH\x00\x42\x10\n\x0e\x63hannel_status\"c\n\x1eVoiceChannel_UpdateASRSettings\x12\x41\n\x0c\x61sr_settings\x18\x01 \x01(\x0b\x32+.asr_settings.ASRSettings_UpdateASRSettings\"e\n\x1dVoiceChannel_UpdateDisclaimer\x12\x44\n\ndisclaimer\x18\x01 \x01(\x0b\x32\x30.agent.DisclaimerMessage_UpdateDisclaimerMessage\"F\n\x1bWebChatChannel_UpdateStatus\x12\'\n\x06status\x18\x01 \x01(\x0e\x32\x17.channels.ChannelStatus*&\n\x0b\x43hannelType\x12\t\n\x05VOICE\x10\x00\x12\x0c\n\x08WEB_CHAT\x10\x01*-\n\rChannelStatus\x12\x0f\n\x0bNOT_CREATED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'channels_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CHANNELTYPE']._serialized_start=1904
  _globals['_CHANNELTYPE']._serialized_end=1942
  _globals['_CHANNELSTATUS']._serialized_start=1944
  _globals['_CHANNELSTATUS']._serialized_end=1989
  _globals['_STYLEPROMPT']._serialized_start=155
  _globals['_STYLEPROMPT']._serialized_end=332
  _globals['_STYLEPROMPT_UPDATESTYLEPROMPT']._serialized_start=334
  _globals['_STYLEPROMPT_UPDATESTYLEPROMPT']._serialized_end=381
  _globals['_CHANNELCONFIG']._serialized_start=384
  _globals['_CHANNELCONFIG']._serialized_end=600
  _globals['_VOICECHANNEL']._serialized_start=603
  _globals['_VOICECHANNEL']._serialized_end=753
  _globals['_WEBCHATCHANNEL']._serialized_start=755
  _globals['_WEBCHATCHANNEL']._serialized_end=853
  _globals['_CHANNELS']._serialized_start=855
  _globals['_CHANNELS']._serialized_end=948
  _globals['_CHANNEL_UPDATEGREETING']._serialized_start=950
  _globals['_CHANNEL_UPDATEGREETING']._serialized_end=1069
  _globals['_CHANNEL_UPDATESTYLEPROMPT']._serialized_start=1072
  _globals['_CHANNEL_UPDATESTYLEPROMPT']._serialized_end=1207
  _globals['_CHANNEL_UPDATESAFETYFILTERS']._serialized_start=1210
  _globals['_CHANNEL_UPDATESAFETYFILTERS']._serialized_end=1384
  _globals['_CHANNEL_UPDATELLMSETTINGS']._serialized_start=1387
  _globals['_CHANNEL_UPDATELLMSETTINGS']._serialized_end=1526
  _globals['_CHANNEL_UPDATESTATUS']._serialized_start=1528
  _globals['_CHANNEL_UPDATESTATUS']._serialized_end=1626
  _globals['_VOICECHANNEL_UPDATEASRSETTINGS']._serialized_start=1628
  _globals['_VOICECHANNEL_UPDATEASRSETTINGS']._serialized_end=1727
  _globals['_VOICECHANNEL_UPDATEDISCLAIMER']._serialized_start=1729
  _globals['_VOICECHANNEL_UPDATEDISCLAIMER']._serialized_end=1830
  _globals['_WEBCHATCHANNEL_UPDATESTATUS']._serialized_start=1832
  _globals['_WEBCHATCHANNEL_UPDATESTATUS']._serialized_end=1902
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: snapshot.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from poly.handlers.protobuf import handoff_pb2 as handoff__pb2
from poly.handlers.protobuf import knowledge_base_pb2 as knowledge__base__pb2
from poly.handlers.protobuf import stop_keywords_pb2 as stop__keywords__pb2
from poly.handlers.protobuf import sms_pb2 as sms__pb2
from poly.handlers.protobuf import variant_pb2 as variant__pb2
from poly.handlers.protobuf import llm_settings_pb2 as llm__settings__pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as content__filter__settings__pb2
from poly.handlers.protobuf import asr_settings_pb2 as asr__settings__pb2
from poly.handlers.protobuf import asr_pb2 as asr__pb2
from poly.handlers.protobuf import languages_pb2 as languages__pb2
from poly.handlers.protobuf import flows_pb2 as flows__pb2
from poly.handlers.protobuf import functions_pb2 as functions__pb2
from poly.handlers.protobuf import agent_settings_pb2 as agent__settings__pb2
from poly.handlers.protobuf import transcript_corrections_pb2 as transcript__corrections__pb2
from poly.handlers.protobuf import experimental_config_pb2 as experimental__config__pb2
from poly.handlers.protobuf import pronunciations_pb2 as pronunciations__pb2
from poly.handlers.protobuf import keyphrase_boosting_pb2 as keyphrase__boosting__pb2
from poly.handlers.protobuf import start_function_pb2 as start__function__pb2
from poly.handlers.protobuf import end_function_pb2 as end__function__pb2
from poly.handlers.protobuf import entities_pb2 as entities__pb2
from poly.handlers.protobuf import voice_pb2 as voice__pb2
from poly.handlers.protobuf import api_integrations_pb2 as api__integrations__pb2
from poly.handlers.protobuf import variables_pb2 as variables__pb2
from poly.handlers.protobuf import translations_pb2 as translations__pb2
from poly.handlers.protobuf import channels_pb2 as channels__pb2
from poly.handlers.protobuf import csat_pb2 as csat__pb2
from poly.handlers.protobuf import integrations_pb2 as integrations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0esnapshot.proto\x12\x08snapshot\x1a\rhandoff.proto\x1a\x14knowledge_base.proto\x1a\x13stop_keywords.proto\x1a\tsms.proto\x1a\rvariant.proto\x1a\x12llm_settings.proto\x1a\x1d\x63ontent_filter_settings.proto\x1a\x12\x61sr_settings.proto\x1a\tasr.proto\x1a\x0flanguages.proto\x1a\x0b\x66lows.proto\x1a\x0f\x66unctions.proto\x1a\x14\x61gent_settings.proto\x1a\x1ctranscript_corrections.proto\x1a\x19\x65xperimental_config.proto\x1a\x14pronunciations.proto\x1a\x18keyphrase_boosting.proto\x1a\x14start_function.proto\x1a\x12\x65nd_function.proto\x1a\x0e\x65ntities.proto\x1a\x0bvoice.proto\x1a\x16\x61pi_integrations.proto\x1a\x0fvariables.proto\x1a\x12translations.proto\x1a\x0e\x63hannels.proto\x1a\ncsat.proto\x1a\x12integrations.proto\"\xa6\n\n\x08Snapshot\x12#\n\x08handoffs\x18\x01 \x01(\x0b\x32\x11.handoff.Handoffs\x12\x35\n\x0eknowledge_base\x18\x02 \x01(\x0b\x32\x1d.knowledge_base.KnowledgeBase\x12\x15\n\x03sms\x18\x03 \x01(\x0b\x32\x08.sms.SMS\x12\x36\n\x12variant_management\x18\x04 \x01(\x0b\x32\x1a.variant.VariantManagement\x12\x32\n\rstop_keywords\x18\x05 \x01(\x0b\x32\x1b.stop_keywords.StopKeywords\x12/\n\x0cllm_settings\x18\x06 \x01(\x0b\x32\x19.llm_settings.LLMSettings\x12O\n\x17\x63ontent_filter_settings\x18\x07 \x01(\x0b\x32..content_filter_settings.ContentFilterSettings\x12/\n\x0c\x61sr_settings\x18\x08 \x01(\x0b\x32\x19.asr_settings.ASRSettings\x12\'\n\tlanguages\x18\t \x01(\x0b\x32\x14.languages.Languages\x12\x1b\n\x05\x66lows\x18\n \x01(\x0b\x32\x0c.flows.Flows\x12.\n\x10global_functions\x18\x0b \x01(\x0b\x32\x14.functions.Functions\x12,\n\x0e\x61gent_settings\x18\x0c \x01(\x0b\x32\x14.agent.AgentSettings\x12M\n\x16transcript_corrections\x18\r \x01(\x0b\x32-.transcript_corrections.TranscriptCorrections\x12\x44\n\x13\x65xperimental_config\x18\x0e \x01(\x0b\x32\'.experimental_config.ExperimentalConfig\x12\x36\n\x0epronunciations\x18\x0f \x01(\x0b\x32\x1e.pronunciations.Pronunciations\x12\x43\n\x13keyphrases_boosting\x18\x10 \x01(\x0b\x32&.keyphrase_boosting.KeyphrasesBoosting\x12\x35\n\x0estart_function\x18\x11 \x01(\x0b\x32\x1d.start_function.StartFunction\x12/\n\x0c\x65nd_function\x18\x12 \x01(\x0b\x32\x19.end_function.EndFunction\x12\x1d\n\x06voices\x18\x13 \x01(\x0b\x32\r.voice.Voices\x12$\n\x08\x65ntities\x18\x14 \x01(\x0b\x32\x12.entities.Entities\x12\x15\n\x03\x61sr\x18\x15 \x01(\x0b\x32\x08.asr.Asr\x12;\n\x10\x61pi_integrations\x18\x16 \x01(\x0b\x32!.api_integrations.ApiIntegrations\x12\'\n\tvariables\x18\x17 \x01(\x0b\x32\x14.variables.Variables\x12\x30\n\x0ctranslations\x18\x18 \x01(\x0b\x32\x1a.translations.Translations\x12$\n\x08\x63hannels\x18\x19 \x01(\x0b\x32\x12.channels.Channels\x12\x1e\n\x04\x63sat\x18\x1a \x01(\x0b\x32\x10.csat.CSATConfig\x12\x30\n\x0cintegrations\x18\x1b \x01(\x0b\x32\x1a.integrations.Integrationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SNAPSHOT']._serialized_start=549
  _globals['_SNAPSHOT']._serialized_end=1867
# @@protoc_insertion_point(module_scope)
